% Financial intermediary model with gov't bond pricing and elimination of 
% portfolio costs. Government bonds are modelled as in Woodford (1998, 2001)
% New default mechanism

% Christiaan van der Kwaak
% 15.04.2016

% Update February 2016:  
% - inclusion of time-varying diversion rates lambda_k and lambda_b
% - inclusion of (partial) price-indexation for firms that are not allowed 
% to change prices

% Update April 2016. New default mechanism that we can solve at first order,
% see "default_modeling_2016_04_06.pdf", where we follow Schabert and van 
% Wijnbergen (2014) and Corsetti et al. (2013).

% Update 11 April 2016. We include wage-stickiness into the model a la 
% Ferrero, Eggertsson and Raffo (2014) "Can Structural Reforms Help Europe"
% JME paper.

% Update March 2018: include an investment adjustment shock and update of 
% the Bayesian estimation

% Update April 2018: 
% - eliminate the investment adjustment shock of March 2018.
% - introduction of subjective discount factor shock.
% - calibration of depreciation parameter, no more targeting of steady state 
% investment-output ratio.
% - change of new bankers' net worth provision from linear in previous period 
% assets to linear in previous period net worth.

% Second update April 2018:
% - replacement of Calvo-pricing by Rotemberg-pricing

%--------------------------------------------------------------------------
% Declarations
%--------------------------------------------------------------------------

var 

        // Households
        c, lambda, h, welf,

        // Financial intermediaries
        nu_k, nu_b, eta, phi, mu, n, s_k, s_b, p, d, weight, x, x_k, x_b, 

        // Prices (financial intermediaries)
        q_k, q_b, r_k, r_b, r_d, r_p, Erk, Erb, Ecs, Erp, 

        // Prices (real economy)
        w, m, pi, pi_star, pi_adj, Ksi_1, Ksi_2, Delta, 
        
        // Wages
        omega, omega_new, omega_adj, Ksi_1_w, Ksi_2_w, Delta_w, 

        // Goods producers
        i, k, y,

        // Government
        b, g, g_til, n_g, n_g_til, tau, aa, bb,

        // Central Bank
        r_n, 

        // Default variables
        p_def, b_max, 

        // Exogenous variables
        z, ksi, lambda_k, lambda_b, 
        c_shock, h_shock, i_shock, epsilon_p, epsilon_w, 

        // Auxiliary variables
        R_k, R_b, R_d, R_n, 

        // Observation variables
        % y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, n_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, s_b_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, pi_obs, w_obs, h_obs, n_obs, s_b_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, w_obs, h_obs, n_obs, r_n_obs;
        % y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, n_obs, r_n_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, n_obs, r_n_obs;
        % y_obs, c_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;
        % y_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;
        % c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;
        
        % y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, r_n_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, pi_obs, w_obs, h_obs, n_obs, r_n_obs;
        % y_obs, c_obs, i_obs, Ecs_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;
        
        % y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, r_n_obs, p_obs;
        
        % Switch from net nominal interest r_n_obs to gross nominal interest rate R_n_obs as observable
        % y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, R_n_obs, p_obs;
        % y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, R_n_obs, p_obs;

        % AFTER COMMENTS OF ARTURAS JUODIS NO MORE ESTIMATION OF VOLUMES OF FINANCIAL VARIABLES
        y_obs, c_obs, i_obs, pi_obs, w_obs, h_obs, R_n_obs, R_b_obs;
        
% varexo e_z, e_ksi, e_a, e_r, e_lam_k, e_c;
% varexo e_z, e_ksi, e_a, e_r, e_lam_k, e_c, e_i, e_p, e_w;
varexo e_z, e_ksi, e_a, e_r, e_lam_k, e_c, e_i, e_p;
% varexo e_z, e_ksi, e_a, e_r, e_lam_k, e_c, e_i, e_h;
% varexo e_z, e_ksi, e_a, e_r, e_lam_k, e_c, e_i;
% varexo e_z, e_ksi, e_a, e_r, e_c, e_i, e_p, e_w;

parameters 
        alpha       ${\alpha}$          (long_name = 'effective capital share')
        beta        ${\beta}$           (long_name = 'subjective discount factor')
        gamma       ${\gamma}$          (long_name = 'investment adjustment costs')
        delta       ${\delta}$          (long_name = 'depreciation rate')
        upsilon     ${\upsilon}$        (long_name = 'degree of habit formation')
        varphi      ${\varphi}$         (long_name = 'inverse Frisch elasticity')
        % dis_lab                   % dis_lab is commented out as it is not a parameter anymore but defined within the model section through #dis_lab = .....
        kappa_p     ${\kappa_p}$        (long_name = 'price adjustment costs')
        kappa_w     ${\kappa_w}$        (long_name = 'wage adjustment costs')
        eps_p       ${\epsilon_p}$      (long_name = 'elasticity of substit. (goods)')
        eps_w       ${\epsilon_w}$      (long_name = 'elasticity of substit. (labor)')
        psi_p       ${\psi_p}$          (long_name = 'Calvo prob. (prices)')
        psi_w       ${\psi_w}$          (long_name = 'Calvo prob. (wages)')
        gamma_p     ${\gamma_p}$        (long_name = 'price indexaion')
        gamma_w     ${\gamma_w}$        (long_name = 'wage indexation')
        theta       ${\theta}$          (long_name = 'survival rate of bankers')                        % theta is commented out as it is not a parameter anymore but defined within the model section through #theta = .....
        lambda_b_k  ${\lambda_b/\lambda_k}$         (long_name = 'relative diversion rate')
        rho         ${\rho}$           (long_name = 'maturity govt bonds')
        r_c         ${r_c}$             (long_name = 'coupon payment govt bonds')
        % chi         ${\chi}$           (long_name = 'new bankers net worth')                              % chi is commented out as it is not a parameter anymore but defined within the model section through #chi = .....
        vartheta_cf, vartheta_p, alpha_b, beta_b,
        kappa_b     ${\kappa_b}$        (long_name = 'tax feedback')
        kappa_g     ${\kappa_g}$        (long_name = 'spending feedback')
        kappa_n     ${\kappa_n}$        (long_name = 'recap feedback')
        kappa_pi    ${\kappa_{\pi}}$    (long_name = 'inflation feedback')
        kappa_y     ${\kappa_y}$        (long_name = 'output feedback')
        kappa_ksi   ${\kappa_{\xi}}$    (long_name = 'cap. quality feedback')
        kappa_e_ksi ${\kappa_{\varepsilon_{\xi}}}$           (long_name = 'cap. quality shock feedback')
        rho_z       ${\rho_z}$          (long_name = 'AR(1) productivity')
        rho_ksi     ${\rho_{\xi}}$      (long_name = 'AR(1) cap. quality')
        rho_g       ${\rho_g}$          (long_name = 'AR(1) govt spending')
        rho_r       ${\rho_r}$          (long_name = 'interest smoothing')
        rho_lam_k   ${\rho_{\lambda_{k}}}$           (long_name = 'AR(1) diversion rate')
        rho_c       ${\rho_c}$          (long_name = 'AR(1) consumption')
        rho_h       ${\rho_h}$          (long_name = 'AR(1) disutility labor')
        rho_i       ${\rho_i}$          (long_name = 'AR(1) investment')
        rho_p       ${\rho_p}$          (long_name = 'AR(1) elasticity prices')
        rho_w       ${\rho_w}$          (long_name = 'AR(1) elasticity wages') 
        % stderr(e_ksi) ${\varepsilon_{\xi}}$  (long_name = 'std. capital quality shock')
        sigshock_z, sigshock_ksi, sigshock_u, sigshock_a, sigshock_r, sigshock_lam_k, 
        sigshock_c, sigshock_h, sigshock_i, sigshock_p, sigshock_w, 
        varkappa1, varkappa2, varlambda1, varlambda2, 
        zeta1, zeta2, varzeta1, varzeta2, vartheta1, vartheta2, 
        g_y, tb, 

        // steady state values 
        
        // Households
        c_ss, h_ss, welf_ss, 
        % c_ss, lambda_ss, h_ss, welf_ss,                                   % lambda_ss is commented out as it is not a parameter anymore but defined within the model section through #lambda_ss = .....

        // Financial intermediaries
        nu_b_ss, phi_ss, mu_ss, s_k_ss, 
        % nu_k_ss, nu_b_ss, eta_ss, phi_ss, mu_ss, n_ss, s_k_ss, s_b_ss,    % nu_k_ss, eta_ss, n_ss and s_b_ss are commented out as they are not a parameter anymore but defined within the model section through #nu_k_ss = ..... etc.
        p_ss, d_ss, weight_ss, x_ss, xk_ss, xb_ss, 


        // Prices (financial intermediaries)
        q_k_ss, rk_ss, rd_ss, rp_ss, 
        % q_k_ss, q_b_ss, rk_ss, rb_ss, rd_ss, rp_ss,                       % q_b_ss and rb_ss are commented out as they are not a parameter anymore but defined within the model section through #q_b_ss = ..... etc.
        Erk_ss, Erb_ss, Ecs_ss, Erp_ss, 

        // Prices (real economy)
        w_ss, m_ss, pi_ss, pi_star_ss, pi_adj_ss, Ksi_1_ss, Ksi_2_ss, Delta_ss, 

        // Wages
        omega_ss, omega_new_ss, omega_adj_ss, Ksi_1_w_ss, Ksi_2_w_ss, Delta_w_ss, 

        // Goods producers
        i_ss, k_ss, y_ss, 

        // Government
        g_ss, g_til_ss, n_g_ss, n_g_til_ss, aa_ss, bb_ss, 
        % b_ss, g_ss, g_til_ss, n_g_ss, n_g_til_ss, tau_ss, aa_ss, bb_ss,   % b_ss and tau_ss are commented out as they are not a parameter anymore but defined within the model section through #b_ss = ..... etc.
        qb_ss, qb_max_ss,                                                   % additional parameter is introduced for the correct calculation of #tau_ss in the Bayesian estimation

        // Central Bank
        rn_ss, 

        // Default variables
        p_def_ss,
        % p_def_ss, b_max_ss,                                                 % b_max_ss is commented out as it is not a parameter anymore but defined within the model section through #b_max_ss = .....

        // Exogenous variables
        z_ss, ksi_ss, lambda_b_ss, 
        % z_ss, ksi_ss, lambda_k_ss, lambda_b_ss,                           % lambda_k_ss is commented out as it is not a parameter anymore but defined within the model section through #lambda_k_ss = .....
        c_shock_ss, h_shock_ss, i_shock_ss, epsilon_p_ss, epsilon_w_ss

        // Auxiliary variables
        R_k_ss, R_b_ss, R_d_ss, R_n_ss;



%--------------------------------------------------------------------------
% 2. Parameter values
%--------------------------------------------------------------------------

load parametervalues;
set_param_value('alpha'      ,par.alpha);
set_param_value('beta'       ,par.beta);
set_param_value('gamma'      ,par.gamma);
set_param_value('delta'      ,par.delta);
set_param_value('upsilon'    ,par.upsilon);
set_param_value('varphi'     ,par.varphi);
% set_param_value('dis_lab'    ,par.dis_lab);           % dis_lab is commented out as it is not a parameter anymore but defined within the model section through #dis_lab = .....
set_param_value('kappa_p'    ,par.kappa_p);
set_param_value('kappa_w'    ,par.kappa_w);
set_param_value('eps_p'      ,par.eps_p);
set_param_value('eps_w'      ,par.eps_w);
set_param_value('psi_p'      ,par.psi_p);
set_param_value('psi_w'      ,par.psi_w);
set_param_value('gamma_p'    ,par.gamma_p);
set_param_value('gamma_w'    ,par.gamma_w);             
set_param_value('theta'      ,par.theta);             % theta is commented out as it is not a parameter anymore but defined within the model section through #theta = .....
% set_param_value('chi'        ,par.chi);               % chi is commented out as it is not a parameter anymore but defined within the model section through #chi = .....
set_param_value('lambda_b_k' ,par.lambda_b_k);
set_param_value('rho'        ,par.rho);
set_param_value('r_c'        ,par.r_c);
set_param_value('vartheta_cf',par.vartheta_cf);
set_param_value('vartheta_p' ,par.vartheta_p);
set_param_value('alpha_b'    ,par.alpha_b);
set_param_value('beta_b'     ,par.beta_b);
set_param_value('kappa_b'    ,par.kappa_b);
set_param_value('kappa_g'    ,par.kappa_g);
set_param_value('kappa_n'    ,par.kappa_n);
set_param_value('kappa_pi'   ,par.kappa_pi);
set_param_value('kappa_y'    ,par.kappa_y);
set_param_value('kappa_ksi'  ,par.kappa_ksi);
set_param_value('kappa_e_ksi',par.kappa_e_ksi);
set_param_value('rho_z'      ,par.rho_z);
set_param_value('rho_ksi'    ,par.rho_ksi);
set_param_value('rho_g'      ,par.rho_g);
set_param_value('rho_r'      ,par.rho_r);
set_param_value('rho_lam_k'  ,par.rho_lam_k);
set_param_value('rho_c'      ,par.rho_c);
set_param_value('rho_h'      ,par.rho_h);
set_param_value('rho_i'      ,par.rho_i);
set_param_value('rho_p'      ,par.rho_p);
set_param_value('rho_w'      ,par.rho_w);
set_param_value('sigshock_z' ,par.sigshock_z);
set_param_value('sigshock_ksi',par.sigshock_ksi);
set_param_value('sigshock_r' ,par.sigshock_r);
set_param_value('sigshock_u' ,par.sigshock_u);
set_param_value('sigshock_a' ,par.sigshock_a);
set_param_value('sigshock_lam_k',par.sigshock_lam_k);
set_param_value('sigshock_c' ,par.sigshock_c);
set_param_value('sigshock_h' ,par.sigshock_h);
set_param_value('sigshock_i' ,par.sigshock_i);
set_param_value('sigshock_p' ,par.sigshock_p);
set_param_value('sigshock_w' ,par.sigshock_w);
set_param_value('varkappa1'  ,par.varkappa1);
set_param_value('varkappa2'  ,par.varkappa2);
set_param_value('varlambda1' ,par.varlambda1);
set_param_value('varlambda2' ,par.varlambda2);
set_param_value('zeta1'      ,par.zeta1);
set_param_value('zeta2'      ,par.zeta2);
set_param_value('varzeta1'   ,par.varzeta1);
set_param_value('varzeta2'   ,par.varzeta2);
set_param_value('vartheta1'  ,par.vartheta1);
set_param_value('vartheta2'  ,par.vartheta2);
set_param_value('g_y'        ,par.g_y);
set_param_value('tb'         ,par.tb);

set_param_value('c_ss'       ,par.c_ss);
% set_param_value('lambda_ss'  ,par.lambda_ss);                             % lambda_ss is commented out as it is not a parameter anymore but defined within the model section through #lambda_ss = .....
set_param_value('h_ss'       ,par.h_ss);
set_param_value('welf_ss'    ,par.welf_ss);

% set_param_value('nu_k_ss'    ,par.nu_k_ss);                               % nu_k_ss is commented out as it is not a parameter anymore but defined within the model section through #nu_k_ss = .....
set_param_value('nu_b_ss'    ,par.nu_b_ss);
% set_param_value('eta_ss'     ,par.eta_ss);                                % eta_ss is commented out as it is not a parameter anymore but defined within the model section through #eta_ss = .....
set_param_value('phi_ss'     ,par.phi_ss);
set_param_value('mu_ss'      ,par.mu_ss);
% set_param_value('n_ss'       ,par.n_ss);                                  % n_ss is commented out as it is not a parameter anymore but defined within the model section through #n_ss = .....
set_param_value('s_k_ss'     ,par.s_k_ss);
% set_param_value('s_b_ss'     ,par.s_b_ss);                                % s_b_ss is commented out as it is not a parameter anymore but defined within the model section through #s_b_ss = .....
set_param_value('p_ss'       ,par.p_ss);
set_param_value('d_ss'       ,par.d_ss);
set_param_value('weight_ss'  ,par.weight_ss);
set_param_value('x_ss'       ,par.x_ss);
set_param_value('xk_ss'      ,par.xk_ss);
set_param_value('xb_ss'      ,par.xb_ss);

set_param_value('q_k_ss'     ,par.q_k_ss);
% set_param_value('q_b_ss'     ,par.q_b_ss);                                % q_b_ss is commented out as it is not a parameter anymore but defined within the model section through #q_b_ss = .....
set_param_value('rk_ss'      ,par.rk_ss);
% set_param_value('rb_ss'      ,par.rb_ss);                                 % rb_ss is commented out as it is not a parameter anymore but defined within the model section through #rb_ss = .....
set_param_value('rd_ss'      ,par.rd_ss);
set_param_value('rp_ss'      ,par.rp_ss);
set_param_value('Erk_ss'     ,par.Erk_ss);
set_param_value('Erb_ss'     ,par.Erb_ss);
set_param_value('Ecs_ss'     ,par.Ecs_ss);
set_param_value('Erp_ss'     ,par.Erp_ss);

set_param_value('w_ss'       ,par.w_ss);
set_param_value('m_ss'       ,par.m_ss);
set_param_value('pi_ss'      ,par.pi_ss);
set_param_value('pi_star_ss' ,par.pi_star_ss);
set_param_value('pi_adj_ss'  ,par.pi_adj_ss);
set_param_value('Ksi_1_ss'   ,par.Ksi_1_ss);
set_param_value('Ksi_2_ss'   ,par.Ksi_2_ss);
set_param_value('Delta_ss'   ,par.Delta_ss);

set_param_value('omega_ss'   ,par.omega_ss);
set_param_value('omega_new_ss',par.omega_new_ss);
set_param_value('omega_adj_ss',par.omega_adj_ss);
set_param_value('Ksi_1_w_ss' ,par.Ksi_1_w_ss);
set_param_value('Ksi_2_w_ss' ,par.Ksi_2_w_ss);
set_param_value('Delta_w_ss' ,par.Delta_w_ss);

set_param_value('i_ss'       ,par.i_ss);
set_param_value('k_ss'       ,par.k_ss);
set_param_value('y_ss'       ,par.y_ss);

% set_param_value('b_ss'       ,par.b_ss);                                  % b_ss is commented out as it is not a parameter anymore but defined within the model section through #b_ss = .....
set_param_value('g_ss'       ,par.g_ss);
set_param_value('g_til_ss'   ,par.g_til_ss);
set_param_value('n_g_ss'     ,par.n_g_ss);
set_param_value('n_g_til_ss' ,par.n_g_til_ss);
% set_param_value('tau_ss'     ,par.tau_ss);                                % tau_ss is commented out as it is not a parameter anymore but defined within the model section through #tau_ss = .....
set_param_value('aa_ss'      ,par.aa_ss);
set_param_value('bb_ss'      ,par.bb_ss);
set_param_value('qb_ss'      ,par.qb_ss);
set_param_value('qb_max_ss'  ,par.qb_max_ss);

set_param_value('rn_ss'      ,par.rn_ss);

set_param_value('p_def_ss'   ,par.p_def_ss);
% set_param_value('b_max_ss'   ,par.b_max_ss);                              % b_max_ss is commented out as it is not a parameter anymore but defined within the model section through #b_max_ss = .....

set_param_value('z_ss'       ,par.z_ss);
set_param_value('ksi_ss'     ,par.ksi_ss);
% set_param_value('lambda_k_ss',par.lambda_k_ss);                           % lambda_k_ss is commented out as it is not a parameter anymore but defined within the model section through #lambda_k_ss = .....
set_param_value('lambda_b_ss',par.lambda_b_ss);
set_param_value('c_shock_ss' ,par.c_shock_ss);
set_param_value('h_shock_ss' ,par.h_shock_ss);
set_param_value('i_shock_ss' ,par.i_shock_ss);
set_param_value('epsilon_p_ss',par.eps_p);
set_param_value('epsilon_w_ss',par.eps_w);
set_param_value('R_k_ss'     ,par.R_k_ss);
set_param_value('R_b_ss'     ,par.R_b_ss);
set_param_value('R_d_ss'     ,par.R_d_ss);
set_param_value('R_n_ss'     ,par.R_n_ss);


external_function(name = betacdf, nargs = 3, first_deriv_provided = betapdf);
% external_function(name = betacdf, nargs = 3);
%--------------------------------------------------------------------------
% 3. Model equations
%--------------------------------------------------------------------------

//*************************************************************************
// Model version in levels
//*************************************************************************

/*
model;

% variables of which the steady state explicitly shows up in the FOCs:
% y_ss, 
% pi_ss, pi_star_ss, Ksi_1_ss, Ksi_2_ss, Delta_ss,
% omega_ss, omega_new_ss, Ksi_1_w_ss, Ksi_2_w_ss, Delta_w_ss,
% lambda_k_ss,
% tau_ss, b_max_ss, 
% rn_ss

% IMPORTANT: variables of the above that are AFFECTED by changes 
% in theta and lambda_b_k:
% lambda_k_ss,
% tau_ss, b_max_ss


#lambda_ss                  = (1-beta*upsilon)/((1-upsilon)*c_ss);                                        % steady state value of marginal utility of consumption
#dis_lab                    = ((epsilon_w_ss-1)/epsilon_w_ss)*lambda_ss*w_ss/(h_shock_ss*h_ss^varphi);    % disutility of labor constant

#q_b_ss                     = (1-p_def_ss*vartheta_cf)*r_c/((1+rd_ss+lambda_b_k*(rk_ss-rd_ss))*pi_ss-(1-p_def_ss*vartheta_p)*(1-rho));  % steady state bond price
#rb_ss                      = (r_c+(1-rho)*q_b_ss)/(pi_ss*q_b_ss)-1;        % steady state return on government consols before default
#tau_ss                     = rb_ss*qb_ss+g_ss+n_g_ss-n_g_til_ss;           % steady state level of lump sum taxes. tau_ss changes with lambda_b_k. q_b_ss*b_ss is constant through calibration, but rb_ss is not, and hence rb_ss*q_b_ss*b_ss is also not constant!!!!!
#b_ss                       = qb_ss/q_b_ss;                                 % steady state number of government bonds
#b_max_ss                   = qb_max_ss/q_b_ss;                             % steady state maximum number of government bonds. b_max_ss changes with lambda_b_k as q_b_ss changes with lambda_b_k, so does b_max_ss = qb_ss/q_b_ss
#s_b_ss                     = b_ss;                                         % steady state value of loans to government
#n_ss                       = (q_k_ss*s_k_ss+lambda_b_k*q_b_ss*s_b_ss)/phi_ss;  % steady state value of net worth

% #chi                        = (n_ss-theta*((rk_ss-rd_ss)*q_k_ss*s_k_ss+(rb_ss-rd_ss)*q_b_ss*s_b_ss+(1+rd_ss)*n_ss))/p_ss;               % fraction of net worth that goes to starting bankers (linear in previous period total assets)
#chi                        = (n_ss-theta*((rk_ss-rd_ss)*q_k_ss*s_k_ss+(rb_ss-rd_ss)*q_b_ss*s_b_ss+(1+rd_ss)*n_ss))/n_ss;               % fraction of net worth that goes to starting bankers (linear in previous period net worth)
% #chi                        = 1-theta*(Ecs_ss*phi_ss+1+rd_ss);

#eta_ss                     = beta*(1-theta)*(1+rd_ss)/(1-beta*theta*((1+rd_ss)+(rk_ss-rd_ss)*phi_ss));                                 % steady state values eta
#nu_k_ss                    = ((rk_ss-rd_ss)/(1+rd_ss))*eta_ss;             % steady state values nu_k
#lambda_k_ss                = nu_k_ss+eta_ss/phi_ss;                        % calibrated parameter value for fraction of private loans banker can divert


// Households

% lambda  = 1/(c-upsilon*c(-1))-beta*upsilon/(c(+1)-upsilon*c);
lambda  = c_shock/(c-upsilon*c(-1))-beta*upsilon*c_shock(+1)/(c(+1)-upsilon*c);
% lambda*w = (h_shock*dis_lab)*h^(varphi);
beta*(lambda(+1)*(1+r_d(+1))/lambda) = 1;
welf    = c_shock*log(c-upsilon*c(-1))-(h_shock*dis_lab)*h^(1+varphi)/(1+varphi)+beta*welf(+1);


// Financial Intermediaries

1+r_p   = (1+r_k)*weight(-1)+(1+r_b)*(1-weight(-1));
eta     = beta*((lambda(+1)/lambda)*(1-theta+theta*(eta(+1)+nu_k(+1)*phi(+1)))*(1+r_d(+1)+aa(+1)-bb(+1)));
nu_k    = beta*((lambda(+1)/lambda)*(1-theta+theta*(eta(+1)+nu_k(+1)*phi(+1)))*(r_k(+1)-r_d(+1)));
nu_b    = beta*((lambda(+1)/lambda)*(1-theta+theta*(eta(+1)+nu_k(+1)*phi(+1)))*(r_b(+1)-r_d(+1)-p_def(+1)*((vartheta_cf*r_c+vartheta_p*(1-rho)*q_b(+1))/(pi(+1)*q_b))));
nu_b    = (lambda_b/lambda_k)*nu_k;
phi     = eta/(lambda_k-nu_k);
1+r_d   = (1+r_n(-1))/pi;
% 1+r_d   = r_n(-1)/pi;
q_k*s_k = weight*p;
q_k*s_k+(lambda_b/lambda_k)*q_b*s_b = phi*n;
% n       = theta*((r_k-r_d)*q_k(-1)*s_k(-1)+(r_b-r_d)*q_b(-1)*s_b(-1)+(1+r_d)*n(-1))+chi*p(-1)+n_g-n_g_til;
n       = theta*((r_k-r_d)*q_k(-1)*s_k(-1)+(r_b-r_d)*q_b(-1)*s_b(-1)+(1+r_d)*n(-1))+chi*n(-1)+n_g-n_g_til;
p       = q_k*s_k+q_b*s_b;
d       = p-n;
Erk     = r_k(+1);
Erb     = r_b(+1);
Ecs     = r_k(+1)-r_d(+1);
Erp     = r_p(+1);
mu      = nu_k/(lambda_k-nu_k);
x       = p(+1)/p;
x_k     = s_k(+1)/s_k;
x_b     = s_b(+1)/s_b;
1+r_b   = (r_c+(1-rho)*q_b)/(pi*q_b(-1));
p_def   = 0;  % results should be exactly the same as the no default model.
% p_def   = betacdf(b/(4*y_ss*b_max),alpha_b,beta_b);


// Price Setting

kappa_p*(pi - pi_adj*pi_ss^(1-gamma_p))*pi*y = (1-epsilon_p)*y + epsilon_p*m*y + beta*(lambda(+1)/lambda)*kappa_p*(pi(+1) - pi_adj(+1)*pi_ss^(1-gamma_p))*pi(+1)*y(+1);
pi_adj  = pi(-1)^gamma_p;

pi_star = pi_star_ss;
Ksi_1   = Ksi_1_ss;
Ksi_2   = Ksi_2_ss;
Delta   = Delta_ss;

// Wage Setting

kappa_w*(omega - omega_adj*omega_ss^(1-gamma_w))*omega*w = (1-epsilon_w)*w*h + epsilon_w*(h_shock*dis_lab)*h^(1+varphi)/lambda + beta*(lambda(+1)/lambda)*kappa_w*(omega(+1) - omega_adj(+1)*omega_ss^(1-gamma_w))*omega(+1)*w(+1);
omega       = (w/w(-1))*pi;
omega_adj   = omega(-1)^gamma_w;

omega_new   = omega_new_ss;
Ksi_1_w     = Ksi_1_w_ss;
Ksi_2_w     = Ksi_2_w_ss;
Delta_w     = Delta_w_ss;


// Production Side
m       = alpha^(-alpha)*(1-alpha)^(alpha-1)*(w^(1-alpha)*(q_k(-1)*(1+r_k)/ksi-q_k*(1-delta))^(alpha))/z;
k       = (1-delta)*ksi*k(-1)+(1-gamma*(i/i(-1)-1)^2/2)*i_shock*i;
1/q_k   = (1-(gamma/2)*(i/i(-1)-1)^2)*i_shock-gamma*(i/i(-1))*(i/i(-1)-1)*i_shock+beta*((lambda(+1)/lambda)*(q_k(+1)/q_k)*(i(+1)/i)^2*gamma*(i(+1)/i-1)*i_shock(+1));
k(-1)/h = (alpha/(1-alpha))*w/(q_k(-1)*(1+r_k)-q_k*(1-delta)*ksi);
y       = z*(ksi*k(-1))^(alpha)*h^(1-alpha);


// Government Policy
g       = g_til+zeta1*(ksi-ksi_ss)+zeta2*(ksi(-4)-ksi_ss)+varzeta1*(lambda_k-lambda_k_ss)+varzeta2*(lambda_k(-4)-lambda_k_ss);
% log(g_til/g_ss) = rho_g*log(g_til(-1)/g_ss)+e_u+e_a(-4);
log(g_til/g_ss) = rho_g*log(g_til(-1)/g_ss)+e_a(-4);
n_g     = aa*n(-1);
% aa      = (varkappa1*(ksi-ksi_ss)+varkappa2*(ksi(-8)-ksi_ss));
aa      = (varkappa1*(ksi-ksi_ss)+varkappa2*(ksi(-4)-ksi_ss)+varlambda1*(lambda_k-lambda_k_ss)+varlambda2*(lambda_k(-8)-lambda_k_ss));
n_g_til = vartheta1*n_g(-4)+vartheta2*n_g(-16);
bb      = n_g_til/n(-1);
tau     = tau_ss+kappa_b*(b(-1)-b_ss)+kappa_g*(g-g_ss)+kappa_n*n_g;
b_max   = b_max_ss;
q_b*b+tau+n_g_til = g+n_g+(1+r_b)*q_b(-1)*b(-1);
r_n = (1-rho_r)*(rn_ss+kappa_pi*(pi-pi_ss)+kappa_y*log(y/y(-1))+kappa_ksi*(ksi-ksi_ss))+rho_r*r_n(-1)-e_r;
% r_n = (1-rho_r)*(rn_ss+kappa_pi*(pi-pi_ss)+kappa_y*log(y/y(-1)))+rho_r*r_n(-1)-kappa_ksi*e_ksi;
%%% Implements +kappa_ksi*(ksi-ksi_ss) term at the end of Taylor rule outside the brackets!!!!!


// Equilibrium Conditions
s_k     = k;
s_b     = b;
y       = c + i + g + (1/2)*kappa_p*(pi-pi_adj*pi_ss^(1-gamma_p))^2*y + (1/2)*kappa_w*(omega - omega_adj*omega_ss^(1-gamma_w))^2*w;

// Exogeneous processes
log(z)          = rho_z*log(z(-1))+e_z;
log(ksi)        = rho_ksi*log(ksi(-1))-e_ksi;
log(lambda_k/lambda_k_ss) = rho_lam_k*log(lambda_k(-1)/lambda_k_ss)+e_lam_k;
lambda_b        = lambda_b_k*lambda_k;
log(c_shock)    = rho_c*log(c_shock(-1))+e_c;
log(h_shock)    = rho_c*log(h_shock(-1));
% log(h_shock)    = rho_c*log(h_shock(-1))+e_h;
% log(i_shock)    = rho_i*log(i_shock(-1));
log(i_shock)    = rho_i*log(i_shock(-1))+e_i;
% log(epsilon_p/epsilon_p_ss) = rho_p*log(epsilon_p(-1)/epsilon_p_ss);
log(epsilon_p/epsilon_p_ss) = rho_p*log(epsilon_p(-1)/epsilon_p_ss)+e_p;
% log(epsilon_w/epsilon_w_ss) = rho_w*log(epsilon_w(-1)/epsilon_w_ss);
log(epsilon_w/epsilon_w_ss) = rho_w*log(epsilon_w(-1)/epsilon_w_ss)+e_w;

// Auxiliary equations
R_k          = 1+r_k;
R_b          = 1+r_b;
R_d          = 1+r_d;
R_n          = 1+r_n;

// Observation equations
y_obs        = y-steady_state(y);
c_obs        = c-steady_state(c);
i_obs        = i-steady_state(i);
% Ecs_obs      = pi_ss*(Ecs-steady_state(Ecs));
s_k_obs      = s_k-steady_state(s_k);
pi_obs       = pi-steady_state(pi);
w_obs        = w-steady_state(w);
h_obs        = h-steady_state(h);
% n_obs        = n-steady_state(n);
p_obs        = p-steady_state(p);
% s_b_obs      = s_b-steady_state(s_b);
% r_n_obs      = r_n-steady_state(r_n);
R_n_obs      = R_n-steady_state(R_n);
% d_obs        = d-steady_state(d);
end;
*/
%--------------------------------------------------------------------------
% 4. Steady states
%--------------------------------------------------------------------------
/*
initval;
c       = c_ss;
lambda  = lambda_ss;
h       = h_ss;
welf    = welf_ss;
nu_k    = nu_k_ss;
nu_b    = nu_b_ss;
eta     = eta_ss;
phi     = phi_ss;
mu      = mu_ss;
n       = n_ss;
s_k     = s_k_ss;
s_b     = s_b_ss;
p       = p_ss;
d       = d_ss;
weight  = weight_ss;
x       = x_ss;
x_k     = xk_ss;
x_b     = xb_ss;
q_k     = q_k_ss;
q_b     = q_b_ss;
r_k     = rk_ss;
r_b     = rb_ss;
r_d     = rd_ss;
r_p     = rp_ss;
Erk     = Erk_ss;
Erb     = Erb_ss;
Ecs     = Ecs_ss;
Erp     = Erp_ss;
w       = w_ss;
m       = m_ss;
pi      = pi_ss;
pi_star = pi_star_ss;
pi_adj  = pi_adj_ss;
Ksi_1   = Ksi_1_ss;
Ksi_2   = Ksi_2_ss;
Delta   = Delta_ss;
omega   = omega_ss;
omega_new = omega_new_ss;
omega_adj = omega_adj_ss;
Ksi_1_w = Ksi_1_w_ss;
Ksi_2_w = Ksi_2_w_ss;
Delta_w = Delta_w_ss;
i       = i_ss;
k       = k_ss;
y       = y_ss;
b       = b_ss;
g       = g_ss;
g_til   = g_til_ss;
n_g     = n_g_ss;
n_g_til = n_g_til_ss;
tau     = tau_ss;
aa      = aa_ss;
bb      = bb_ss;
r_n     = rn_ss;
p_def   = p_def_ss;
b_max   = b_max_ss;
z       = z_ss;
ksi     = ksi_ss;
lambda_k = lambda_k_ss;
lambda_b = lambda_b_ss;
c_shock  = c_shock_ss;
h_shock  = h_shock_ss;
i_shock  = i_shock_ss;
epsilon_p = epsilon_p_ss;
epsilon_w = epsilon_w_ss;
R_k     = R_k_ss;
R_b     = R_b_ss;
R_d      = R_d_ss;
R_n     = R_n_ss;
y_obs   = 0;
c_obs   = 0;
i_obs   = 0;
% Ecs_obs = 0;
s_k_obs = 0;
pi_obs  = 0;
w_obs   = 0;
h_obs   = 0;
% n_obs   = 0;
end;
*/
/*
steady;

check;
*/
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% 5. Shocks and solution
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


%--------------------------------------------------------------------------
% deterministic solver
%--------------------------------------------------------------------------
/*
shocks;
    var e_lam_k;
    periods 1:1;
    values 0.08;
end;

simul(periods=200);

lambda_k_simul  = (oo_.endo_simul(59,5:end)-oo_.steady_state(59))/oo_.steady_state(59)*100;
y_simul         = (oo_.endo_simul(45,5:end)-oo_.steady_state(45))/oo_.steady_state(45)*100;
c_simul         = (oo_.endo_simul(1,5:end)-oo_.steady_state(1))/oo_.steady_state(1)*100;
i_simul         = (oo_.endo_simul(43,5:end)-oo_.steady_state(43))/oo_.steady_state(43)*100;
n_simul         = (oo_.endo_simul(10,5:end)-oo_.steady_state(10))/oo_.steady_state(10)*100;
Ecs_simul       = (oo_.endo_simul(27,5:end)-oo_.steady_state(27))*10000;
p_def_simul     = oo_.endo_simul(55,5:end)*10000;
q_b_simul       = (oo_.endo_simul(20,5:end)-oo_.steady_state(20))/oo_.steady_state(20)*100;
w_simul         = (oo_.endo_simul(29,5:end)-oo_.steady_state(29))/oo_.steady_state(29)*100;
h_simul         = (oo_.endo_simul(3,5:end)-oo_.steady_state(3))/oo_.steady_state(3)*100;
r_n_simul       = (oo_.endo_simul(54,5:end)-oo_.steady_state(54))*10000;
pi_simul        = (oo_.endo_simul(31,5:end)-oo_.steady_state(31))/oo_.steady_state(31)*100;
g_simul         = (oo_.endo_simul(47,5:end)-oo_.steady_state(47))/oo_.steady_state(45)*100;


%--------------------------------------------------------------------------
% calculation of cumulative multipliers for deterministic case


tmp_y                   = cumsum(oo_.endo_simul(45,5:end-1));             % note that we start from period 5 as first 4 periods are still steady state
tmp_g                   = cumsum(oo_.endo_simul(47,5:end-1));             % note that we start from period 5 as first 4 periods are still steady state
stat_nonlin.cum_y       = tmp_y(end);
stat_nonlin.cum_g       = tmp_g(end);

lengthperiod            = size(tmp_y,2);

for i=1:lengthperiod
  dis_fac(i)            = beta^(i-1);
end

tmp_y                   = cumsum(dis_fac.*oo_.endo_simul(45,5:end-1));
tmp_g                   = cumsum(dis_fac.*oo_.endo_simul(47,5:end-1));
stat_nonlin.dis_cum_y   = tmp_y(end);
stat_nonlin.dis_cum_g   = tmp_g(end);

stat_nonlin

if (varzeta2 == 0)      % the file saves only when there is a delayed lambda-shock
    savefile1           = 'transfer1_nonlin_nopolicy.mat';
else
    savefile1           = 'transfer1_nonlin_del_stim.mat';
end

save(savefile1,'stat_nonlin');
*/

%--------------------------------------------------------------------------
% stochastic solver
%--------------------------------------------------------------------------
/*
shocks;
var e_z; stderr sigshock_z;
var e_ksi; stderr sigshock_ksi;
% var e_u; stderr sigshock_u;
var e_a; stderr sigshock_a;
var e_r; stderr sigshock_r;
var e_lam_k; stderr sigshock_lam_k;
var e_c; stderr sigshock_c;
end;

% shocks for capital quality and government spending are turned off for Spain paper

steady;
stoch_simul(order=1,irf=40,nocorr,nomoments,nograph,pruning,replic=3000); 


%--------------------------------------------------------------------------
%--------------------------------------------------------------------------



//*************************************************************************
// Prepare plots
//*************************************************************************

width       = 0.5;  
fsize       = 8;
fsize_alt   = 8;
zero_style  = ':k';
line_style  = 'r-.';
period      = 40;
time        = 1:period;
zero        = time*0;


//*************************************************************************
// Shock to diversion rate lambda_k and lambda_b
//*************************************************************************





if 0

%--------------------------------------------------------------------------
% figures deterministic solver
%--------------------------------------------------------------------------

f21=figure(21);

subplot(3,2,1)
plot(time,lambda_k_simul(1:period),line_style,'LineWidth',width)
hold on, box off
title('Diversion rate private loans','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,y_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,c_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,4)
plot(time,i_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

f22=figure(22);

subplot(3,2,1)
plot(time,n_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Net Worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,Ecs_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit Spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,p_def_simul(1:period),line_style,'LineWidth',width)
hold on, box off
title('Default Probability','FontSize',fsize)
ylabel({'Abs. level.';'of indicator'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,3)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off

subplot(3,2,4)
plot(time,q_b_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


f23=figure(23);

subplot(3,2,1)
plot(time,w_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Wages','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,h_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Labor','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,r_n_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,4)
plot(time,pi_simul(1:period),line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Inflation','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

else
%--------------------------------------------------------------------------
% figures stochastic solver
%--------------------------------------------------------------------------


% f21=figure(21);
f21=figure(61);

subplot(3,2,1)
plot(time,oo_.irfs.lambda_k_e_lam_k/oo_.steady_state(59)*100,line_style,'LineWidth',width)
hold on, box off
title('Diversion rate private loans','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.y_e_lam_k/y_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,oo_.irfs.c_e_lam_k/c_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,4)
plot(time,oo_.irfs.i_e_lam_k/i_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

% f22=figure(22);
f22=figure(62);

subplot(3,2,1)
plot(time,oo_.irfs.n_e_lam_k/oo_.steady_state(10)*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Net Worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.Ecs_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit Spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,(oo_.irfs.p_def_e_lam_k+p_def_ss)*10000,line_style,'LineWidth',width)
hold on, box off
title('Default Probability','FontSize',fsize)
ylabel({'Abs. level.';'of indicator'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,3)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off

subplot(3,2,4)
plot(time,oo_.irfs.q_b_e_lam_k/oo_.steady_state(20)*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


% f23=figure(23);
f23=figure(63);

subplot(3,2,1)
plot(time,oo_.irfs.w_e_lam_k/w_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Wages','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.h_e_lam_k/h_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Labor','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,oo_.irfs.r_n_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,4)
plot(time,oo_.irfs.pi_e_lam_k/pi_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Inflation','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

end

if 0
    directory=[pwd '\graphs\papers'];
    filename1=[directory '\default_ord_2_lambda_shock_rho_r_0_8_nopolicy_vs_del_recap_0_03GDP_series1'];
    print(f21,'-dpdf',filename1)
    saveas(f21,filename1,'fig')

    filename2=[directory '\default_ord_2_lambda_shock_rho_r_0_8_nopolicy_vs_del_recap_0_03GDP_series2'];
    print(f22,'-dpdf',filename2)
    saveas(f22,filename2,'fig')

    filename3=[directory '\default_ord_2_lambda_shock_rho_r_0_8_nopolicy_vs_del_recap_0_03GDP_series3'];
    print(f23,'-dpdf',filename3)
    saveas(f23,filename3,'fig')
end

if 0
    directory=[pwd '\graphs\papers'];
    filename1=[directory '\default_ord_2_lambda_shock_rho_r_0_8_del_recap_vs_ESM_recap_0_03GDP_series1'];
    print(f21,'-dpdf',filename1)
    saveas(f21,filename1,'fig')

    filename2=[directory '\default_ord_2_lambda_shock_rho_r_0_8_del_recap_vs_ESM_recap_0_03GDP_series2'];
    print(f22,'-dpdf',filename2)
    saveas(f22,filename2,'fig')

    filename3=[directory '\default_ord_2_lambda_shock_rho_r_0_8_del_recap_vs_ESM_recap_0_03GDP_series3'];
    print(f23,'-dpdf',filename3)
    saveas(f23,filename3,'fig')
end
*/


//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
// Model version in logs
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************
//*************************************************************************


model;

% variables of which the steady state explicitly shows up in the FOCs:
% y_ss, 
% pi_ss, pi_star_ss, Ksi_1_ss, Ksi_2_ss, Delta_ss,
% omega_ss, omega_new_ss, Ksi_1_w_ss, Ksi_2_w_ss, Delta_w_ss,
% lambda_k_ss,
% tau_ss, b_max_ss, 
% rn_ss

% IMPORTANT: variables of the above that are AFFECTED by changes 
% in theta and lambda_b_k:
% lambda_k_ss,
% tau_ss, b_max_ss


#lambda_ss                  = (1-beta*upsilon)/((1-upsilon)*c_ss);                                        % steady state value of marginal utility of consumption
#dis_lab                    = ((epsilon_w_ss-1)/epsilon_w_ss)*lambda_ss*w_ss/(h_shock_ss*h_ss^varphi);    % disutility of labor constant

#q_b_ss                     = (1-p_def_ss*vartheta_cf)*r_c/((1+rd_ss+lambda_b_k*(rk_ss-rd_ss))*pi_ss-(1-p_def_ss*vartheta_p)*(1-rho));  % steady state bond price
#rb_ss                      = (r_c+(1-rho)*q_b_ss)/(pi_ss*q_b_ss)-1;        % steady state return on government consols before default
#tau_ss                     = rb_ss*qb_ss+g_ss+n_g_ss-n_g_til_ss;           % steady state level of lump sum taxes. tau_ss changes with lambda_b_k. q_b_ss*b_ss is constant through calibration, but rb_ss is not, and hence rb_ss*q_b_ss*b_ss is also not constant!!!!!
#b_ss                       = qb_ss/q_b_ss;                                 % steady state number of government bonds
#b_max_ss                   = qb_max_ss/q_b_ss;                             % steady state maximum number of government bonds. b_max_ss changes with lambda_b_k as q_b_ss changes with lambda_b_k, so does b_max_ss = qb_ss/q_b_ss
#s_b_ss                     = b_ss;                                         % steady state value of loans to government
#n_ss                       = (q_k_ss*s_k_ss+lambda_b_k*q_b_ss*s_b_ss)/phi_ss;  % steady state value of net worth

% #chi                        = (n_ss-theta*((rk_ss-rd_ss)*q_k_ss*s_k_ss+(rb_ss-rd_ss)*q_b_ss*s_b_ss+(1+rd_ss)*n_ss))/p_ss;               % fraction of net worth that goes to starting bankers (linear in previous period total assets)
#chi                        = (n_ss-theta*((rk_ss-rd_ss)*q_k_ss*s_k_ss+(rb_ss-rd_ss)*q_b_ss*s_b_ss+(1+rd_ss)*n_ss))/n_ss;               % fraction of net worth that goes to starting bankers (linear in previous period net worth)
% #chi                        = 1-theta*(Ecs_ss*phi_ss+1+rd_ss);

% #theta                      = (1-chi)*n_ss/((rk_ss-rd_ss)*q_k_ss*s_k_ss+(rb_ss-rd_ss)*q_b_ss*s_b_ss+(1+rd_ss)*n_ss);

#eta_ss                     = beta*(1-theta)*(1+rd_ss)/(1-beta*theta*((1+rd_ss)+(rk_ss-rd_ss)*phi_ss));                                 % steady state values eta
#nu_k_ss                    = ((rk_ss-rd_ss)/(1+rd_ss))*eta_ss;             % steady state values nu_k
#lambda_k_ss                = nu_k_ss+eta_ss/phi_ss;                        % calibrated parameter value for fraction of private loans banker can divert


// Households

% exp(lambda)  = 1/(exp(c)-upsilon*exp(c(-1)))-beta*upsilon/(exp(c(+1))-upsilon*exp(c));
exp(lambda)  = c_shock/(exp(c)-upsilon*exp(c(-1)))-beta*upsilon*c_shock(+1)/(exp(c(+1))-upsilon*exp(c));
% exp(lambda)*exp(w) = (h_shock*dis_lab)*exp(h)^(varphi);
beta*(exp(lambda(+1))*(1+r_d(+1))/exp(lambda)) = 1;
welf         = c_shock*log(exp(c)-upsilon*exp(c(-1)))-(h_shock*dis_lab)*exp(h)^(1+varphi)/(1+varphi)+beta*welf(+1);


// Financial Intermediaries

1+r_p        = (1+r_k)*exp(weight(-1))+(1+r_b)*(1-exp(weight(-1)));
exp(eta)     = beta*((exp(lambda(+1))/exp(lambda))*(1-theta+theta*(exp(eta(+1))+exp(nu_k(+1))*exp(phi(+1))))*(1+r_d(+1)+aa(+1)-bb(+1)));
exp(nu_k)    = beta*((exp(lambda(+1))/exp(lambda))*(1-theta+theta*(exp(eta(+1))+exp(nu_k(+1))*exp(phi(+1))))*(r_k(+1)-r_d(+1)));
exp(nu_b)    = beta*((exp(lambda(+1))/exp(lambda))*(1-theta+theta*(exp(eta(+1))+exp(nu_k(+1))*exp(phi(+1))))*(r_b(+1)-r_d(+1)-p_def(+1)*((vartheta_cf*r_c+vartheta_p*(1-rho)*exp(q_b(+1)))/(exp(pi(+1))*exp(q_b)))));
exp(nu_b)    = (exp(lambda_b)/exp(lambda_k))*exp(nu_k);
exp(phi)     = exp(eta)/(exp(lambda_k)-exp(nu_k));
1+r_d        = (1+r_n(-1))/exp(pi);
% 1+r_d        = exp(r_n(-1))/exp(pi);
exp(q_k)*exp(s_k) = exp(weight)*exp(p);
exp(q_k)*exp(s_k)+(exp(lambda_b)/exp(lambda_k))*exp(q_b)*exp(s_b) = exp(phi)*exp(n);
% exp(n)       = theta*((r_k-r_d)*exp(q_k(-1))*exp(s_k(-1))+(r_b-r_d)*exp(q_b(-1))*exp(s_b(-1))+(1+r_d)*exp(n(-1)))+chi*exp(p(-1))+n_g-n_g_til;
exp(n)       = theta*((r_k-r_d)*exp(q_k(-1))*exp(s_k(-1))+(r_b-r_d)*exp(q_b(-1))*exp(s_b(-1))+(1+r_d)*exp(n(-1)))+chi*exp(n(-1))+n_g-n_g_til;
exp(p)       = exp(q_k)*exp(s_k)+exp(q_b)*exp(s_b);
exp(d)       = exp(p)-exp(n);
Erk          = r_k(+1);
Erb          = r_b(+1);
Ecs          = r_k(+1)-r_d(+1);
Erp          = r_p(+1);
exp(mu)      = exp(nu_k)/(exp(lambda_k)-exp(nu_k));
x            = exp(p(+1))/exp(p);
x_k          = exp(s_k(+1))/exp(s_k);
x_b          = exp(s_b(+1))/exp(s_b);
1+r_b        = (r_c+(1-rho)*exp(q_b))/(exp(pi)*exp(q_b(-1)));
p_def        = 0;  % results should be exactly the same as the no default model.
% p_def        = betacdf(exp(b)/(4*y_ss*exp(b_max)),alpha_b,beta_b);


// Price Setting

kappa_p*(exp(pi) - exp(pi_adj)*pi_ss^(1-gamma_p))*exp(pi)*exp(y) = (1-epsilon_p)*exp(y) + epsilon_p*exp(m)*exp(y) + beta*(exp(lambda(+1))/exp(lambda))*kappa_p*(exp(pi(+1)) - exp(pi_adj(+1))*pi_ss^(1-gamma_p))*exp(pi(+1))*exp(y(+1));
exp(pi_adj) = exp(pi(-1))^gamma_p;

exp(pi_star) = pi_star_ss;
exp(Ksi_1)   = Ksi_1_ss;
exp(Ksi_2)   = Ksi_2_ss;
exp(Delta)   = Delta_ss;

// Wage Setting

kappa_w*(exp(omega) - exp(omega_adj)*omega_ss^(1-gamma_w))*exp(omega)*exp(w) = (1-epsilon_w)*exp(w)*exp(h) + epsilon_w*(h_shock*dis_lab)*exp(h)^(1+varphi)/exp(lambda) + beta*(exp(lambda(+1))/exp(lambda))*kappa_w*(exp(omega(+1)) - exp(omega_adj(+1))*omega_ss^(1-gamma_w))*exp(omega(+1))*exp(w(+1));
exp(omega)   = (exp(w)/exp(w(-1)))*exp(pi);
exp(omega_adj) = exp(omega(-1))^gamma_w;

exp(omega_new) = omega_new_ss;
exp(Ksi_1_w) = Ksi_1_w_ss;
exp(Ksi_2_w) = Ksi_2_w_ss;
exp(Delta_w) = Delta_w_ss;


// Production Side
exp(m)       = alpha^(-alpha)*(1-alpha)^(alpha-1)*(exp(w)^(1-alpha)*(exp(q_k(-1))*(1+r_k)/ksi-exp(q_k)*(1-delta))^(alpha))/z;
exp(k)       = (1-delta)*ksi*exp(k(-1))+(1-(gamma/2)*(exp(i)/exp(i(-1))-1)^2)*i_shock*exp(i);
1/exp(q_k)   = (1-(gamma/2)*(exp(i)/exp(i(-1))-1)^2)*i_shock-gamma*(exp(i)/exp(i(-1)))*(exp(i)/exp(i(-1))-1)*i_shock+beta*((exp(lambda(+1))/exp(lambda))*(exp(q_k(+1))/exp(q_k))*(exp(i(+1))/exp(i))^2*gamma*(exp(i(+1))/exp(i)-1)*i_shock(+1));
exp(k(-1))/exp(h) = (alpha/(1-alpha))*exp(w)/(exp(q_k(-1))*(1+r_k)-exp(q_k)*(1-delta)*ksi);
exp(y)       = z*(ksi*exp(k(-1)))^(alpha)*exp(h)^(1-alpha);


// Government Policy
exp(g)       = exp(g_til)+zeta1*(ksi-ksi_ss)+zeta2*(ksi(-4)-ksi_ss)+varzeta1*(exp(lambda_k)-lambda_k_ss)+varzeta2*(exp(lambda_k(-4))-lambda_k_ss);
% log(exp(g_til)/g_ss) = rho_g*log(exp(g_til(-1))/g_ss)+e_u+e_a(-4);
log(exp(g_til)/g_ss) = rho_g*log(exp(g_til(-1))/g_ss)+e_a(-4);
n_g     = aa*exp(n(-1));
% aa      = (varkappa1*(ksi-ksi_ss)+varkappa2*(ksi(-8)-ksi_ss));
aa      = (varkappa1*(ksi-ksi_ss)+varkappa2*(ksi(-4)-ksi_ss)+varlambda1*(exp(lambda_k)-lambda_k_ss)+varlambda2*(exp(lambda_k(-8))-lambda_k_ss));
n_g_til = vartheta1*n_g(-4)+vartheta2*n_g(-16);
bb      = n_g_til/exp(n(-1));
exp(tau)     = tau_ss+kappa_b*(exp(b(-1))-b_ss)+kappa_g*(exp(g)-g_ss)+kappa_n*n_g;
exp(b_max)   = b_max_ss;
exp(q_b)*exp(b)+exp(tau)+n_g_til = exp(g)+n_g+(1+r_b)*exp(q_b(-1))*exp(b(-1));
r_n = (1-rho_r)*(rn_ss+kappa_pi*(exp(pi)-pi_ss)+kappa_y*log(exp(y)/exp(y(-1)))+kappa_ksi*(ksi-ksi_ss))+rho_r*r_n(-1)-e_r;
% exp(r_n) = (1-rho_r)*(rn_ss+kappa_pi*(exp(pi)-pi_ss)+kappa_y*log(exp(y)/exp(y(-1)))+kappa_ksi*(ksi-ksi_ss))+rho_r*exp(r_n(-1))-e_r;
% r_n = (1-rho_r)*(rn_ss+kappa_pi*(exp(pi)-pi_ss)+kappa_y*log(exp(y)/exp(y(-1))))+rho_r*r_n(-1)-kappa_ksi*e_ksi;       % VERSION OF THE MODEL WITHOUT CAPITAL QUALITY SHOCK e_ksi
%%% Implements +kappa_ksi*(ksi-ksi_ss) term at the end of Taylor rule outside the brackets!!!!!


// Equilibrium Conditions
exp(s_k)     = exp(k);
exp(s_b)     = exp(b);
exp(y)       = exp(c) + exp(i) + exp(g) + (1/2)*kappa_p*(exp(pi)-exp(pi_adj)*pi_ss^(1-gamma_p))^2*exp(y) + (1/2)*kappa_w*(exp(omega) - exp(omega_adj)*omega_ss^(1-gamma_w))^2*exp(w);

// Exogeneous processes
log(z)      = rho_z*log(z(-1))+e_z;
log(ksi)    = rho_ksi*log(ksi(-1))-e_ksi;
% log(exp(lambda_k)/lambda_k_ss) = rho_lam_k*log(exp(lambda_k(-1))/lambda_k_ss);
log(exp(lambda_k)/lambda_k_ss) = rho_lam_k*log(exp(lambda_k(-1))/lambda_k_ss)+e_lam_k;
exp(lambda_b) = lambda_b_k*exp(lambda_k);
log(c_shock) = rho_c*log(c_shock(-1))+e_c;
log(h_shock) = rho_h*log(h_shock(-1));
% log(h_shock) = rho_h*log(h_shock(-1))+e_h;
% log(i_shock) = rho_i*log(i_shock(-1));
log(i_shock) = rho_i*log(i_shock(-1))+e_i;
% log(epsilon_p/epsilon_p_ss) = rho_p*log(epsilon_p(-1)/epsilon_p_ss);
log(epsilon_p/epsilon_p_ss) = rho_p*log(epsilon_p(-1)/epsilon_p_ss)+e_p;
log(epsilon_w/epsilon_w_ss) = rho_w*log(epsilon_w(-1)/epsilon_w_ss);
% log(epsilon_w/epsilon_w_ss) = rho_w*log(epsilon_w(-1)/epsilon_w_ss)+e_w;

// Auxiliary equations
exp(R_k)     = 1+r_k;
exp(R_b)     = 1+r_b;
exp(R_d)     = 1+r_d;
exp(R_n)     = 1+r_n;

// Observation equations
y_obs        = y-steady_state(y);
c_obs        = c-steady_state(c);
i_obs        = i-steady_state(i);
% Ecs_obs      = pi_ss*(Ecs-steady_state(Ecs));
% s_k_obs      = s_k-steady_state(s_k);
pi_obs       = pi-steady_state(pi);
w_obs        = w-steady_state(w);
h_obs        = h-steady_state(h);
% n_obs        = n-steady_state(n);
% s_b_obs      = s_b-steady_state(s_b);
% r_n_obs      = r_n-steady_state(r_n);
R_n_obs      = R_n-steady_state(R_n);
% p_obs        = p-steady_state(p);
% d_obs        = d-steady_state(d);
R_b_obs      = R_b-steady_state(R_b);
end;

%--------------------------------------------------------------------------
% 4. Steady states
%--------------------------------------------------------------------------
/*
% initval is blocked since lambda_ss cannot be outside the model section if it is not a parameter
initval;
c       = log(c_ss);
lambda  = log(lambda_ss);
h       = log(h_ss);
welf    = welf_ss;
nu_k    = log(nu_k_ss);
nu_b    = log(nu_b_ss);
eta     = log(eta_ss);
phi     = log(phi_ss);
mu      = log(mu_ss);
n       = log(n_ss);
s_k     = log(s_k_ss);
s_b     = log(s_b_ss);
p       = log(p_ss);
d       = log(d_ss);
weight  = log(weight_ss);
x       = x_ss;
x_k     = xk_ss;
x_b     = xb_ss;
q_k     = log(q_k_ss);
q_b     = log(q_b_ss);
r_k     = rk_ss;
r_b     = rb_ss;
r_d     = rd_ss;
r_p     = rp_ss;
Erk     = Erk_ss;
Erb     = Erb_ss;
Ecs     = Ecs_ss;
Erp     = Erp_ss;
w       = log(w_ss);
m       = log(m_ss);
pi      = log(pi_ss);
pi_star = log(pi_star_ss);
pi_adj  = log(pi_adj_ss);
Ksi_1   = log(Ksi_1_ss);
Ksi_2   = log(Ksi_2_ss);
Delta   = log(Delta_ss);
omega   = log(omega_ss);
omega_new = log(omega_new_ss);
omega_adj = log(omega_adj_ss);
Ksi_1_w = log(Ksi_1_w_ss);
Ksi_2_w = log(Ksi_2_w_ss);
Delta_w = log(Delta_w_ss);
i       = log(i_ss);
k       = log(k_ss);
y       = log(y_ss);
b       = log(b_ss);
g       = log(g_ss);
g_til   = log(g_til_ss);
n_g     = n_g_ss;
n_g_til = n_g_til_ss;
tau     = log(tau_ss);
aa      = aa_ss;
bb      = bb_ss;
% r_n     = rn_ss;
r_n     = log(rn_ss);
p_def   = p_def_ss;
b_max   = log(b_max_ss);
z       = z_ss;
ksi     = ksi_ss;
lambda_k = log(lambda_k_ss);
lambda_b = log(lambda_b_ss);
c_shock  = c_shock_ss;
h_shock  = h_shock_ss;
i_shock  = i_shock_ss;
epsilon_p = epsilon_p_ss;
epsilon_w = epsilon_w_ss;
R_k      = log(R_k_ss);
R_b      = log(R_b_ss);
R_d      = log(R_d_ss);
R_n      = log(R_n_ss);
y_obs    = 0;
c_obs    = 0;
i_obs    = 0;
Ecs_obs  = 0;
s_k_obs  = 0;
pi_obs   = 0;
w_obs    = 0;
h_obs    = 0;
n_obs    = 0;
end;
*/

% steady_state_model;
% end;

check;
%--------------------------------------------------------------------------
% 5. Shocks and solution
%--------------------------------------------------------------------------

shocks;
var e_z; stderr sigshock_z;
% var e_u; stderr sigshock_u;
var e_ksi; stderr sigshock_ksi;
var e_a; stderr sigshock_a;
var e_r; stderr sigshock_r;
var e_lam_k; stderr sigshock_lam_k;
var e_c; stderr sigshock_c;
% var e_h; stderr sigshock_h;
var e_i; stderr sigshock_i;
var e_p; stderr sigshock_p;
% var e_w; stderr sigshock_w;
end;

% shocks for current government spending are turned off for Spain paper

steady;

% write_latex_parameter_table; 
% write_latex_definitions; 



//*************************************************************************
// Bayesian estimation
//*************************************************************************
if 1
    estimated_params;
    
    % parameters that do affect the steady state
    upsilon, normal_pdf, 0.7, 0.1;
    % varphi, uniform_pdf, , , 0.1, 5;
    varphi, gamma_pdf, 2, 0.75;
    % theta, uniform_pdf, , ,0.8, 0.96;         % theta should be smaller than 1/(phi_ss*Gamma+1/beta) in order for chi to be larger than zero
    % theta, beta_pdf, 0.95, 0.02;         % theta should be smaller than 1/(phi_ss*Gamma+1/beta) in order for chi to be larger than zero.
    theta, beta_pdf, 0.9, 0.05;         % theta should be smaller than 1/(phi_ss*Gamma+1/beta) in order for chi to be larger than zero.
    % theta, ,0.5,0.97, beta_pdf, 0.9, 0.05;         % theta should be smaller than 1/(phi_ss*Gamma+1/beta) in order for chi to be larger than zero.
    % lambda_b_k, uniform_pdf, , ,0.1, 1.5;
    % lambda_b_k, gamma_pdf, 1, 0.5;
    % chi, inv_gamma_pdf, 0.01,0.05;
    kappa_p, gamma_pdf, 50, 20;
    kappa_w,  gamma_pdf, 50, 20;
    gamma_p, beta_pdf, 0.5, 0.2;
    gamma_w, beta_pdf, 0.5, 0.2;
    
    
    % adjustment costs parameters that do not affect the steady state
    gamma, gamma_pdf, 2.5, 1;
    
    % Taylor rule coefficients
    % % kappa_pi, gamma_pdf, 2, 0.5;
    % % kappa_y, normal_pdf, 0.1, 0.15;
    
    % persistence parameters
    rho_z, beta_pdf,0.8, 0.1;
    rho_ksi, beta_pdf,0.8, 0.1;
    rho_lam_k, beta_pdf,0.8, 0.1;
    rho_c, beta_pdf,0.8, 0.1;
    % rho_h, beta_pdf,0.8, 0.1;
    rho_i, beta_pdf,0.8, 0.1;
    rho_p, beta_pdf,0.8, 0.1;
    % rho_w, beta_pdf,0.8, 0.1;

    % shock paramters
    stderr e_ksi, inv_gamma_pdf,0.01,0.05;
    stderr e_lam_k, inv_gamma_pdf,0.01,0.05;
    stderr e_c, inv_gamma_pdf,0.01,0.05;
    % stderr e_h, inv_gamma_pdf,0.01,0.05;
    stderr e_i, inv_gamma_pdf,0.01,0.05;
    stderr e_p, inv_gamma_pdf,0.01,0.05;
    % stderr e_w, inv_gamma_pdf,0.01,0.05;

    % Spain Buriel posterior means and standard deviations
    kappa_b, gamma_pdf, 0.051, 0.01;
    rho_g, beta_pdf,0.979, 0.01;
    stderr e_z, inv_gamma_pdf,0.009,0.05;
    stderr e_a, inv_gamma_pdf,0.062,0.05;
    end;
    
    write_latex_prior_table;

    % estimated_params_init(use_calibration);
    % theta, 0.9583333333333;
    % lambda_b_k, 0.5;
    % end;

    

    % varobs y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, n_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, s_b_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, pi_obs, w_obs, h_obs, n_obs, s_b_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, w_obs, h_obs, n_obs, r_n_obs;
    % varobs y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, n_obs, r_n_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, n_obs, r_n_obs;
    % varobs y_obs, c_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;
    % varobs y_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;    
    % varobs c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;    
    
    % varobs y_obs, c_obs, i_obs, Ecs_obs, s_k_obs, pi_obs, w_obs, h_obs, r_n_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, pi_obs, w_obs, h_obs, n_obs, r_n_obs;
    % varobs y_obs, c_obs, i_obs, Ecs_obs, pi_obs, w_obs, h_obs, p_obs, r_n_obs;
    
    % varobs y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, r_n_obs, p_obs;
    % varobs y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, R_n_obs, p_obs;
    % varobs y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, h_obs, R_n_obs, p_obs;
    % varobs y_obs, c_obs, i_obs, s_k_obs, pi_obs, w_obs, R_n_obs, p_obs;

    % AFTER COMMENTS OF ARTURAS JUODIS NO MORE ESTIMATION OF VOLUMES OF FINANCIAL VARIABLES
    varobs y_obs, c_obs, i_obs, pi_obs, w_obs, h_obs, R_n_obs, R_b_obs;
    % varobs y_obs, c_obs, i_obs, pi_obs, w_obs, h_obs, R_n_obs;
    
    identification(parameter_set=prior_mean);
    
    % initial_estimation_checks
    
    % estimation(datafile=data_Bayesian_Spain,nobs=40,mode_compute=6,mode_check,mh_nblocks=5,mh_replic=10000, mh_jscale=0.5,filtered_vars) y;
    estimation(datafile=data_Bayesian_Spain,nobs=40,mode_file='FinIntGov_mode.mat',mode_compute=9,mode_check,mh_nblocks=5,mh_replic=100000, mh_jscale=0.46,filtered_vars) y;    % employ 'mode_file=....' to use the mode from the previous estimation
    % estimation(datafile=data_Bayesian_Spain,nobs=40,mode_file='FinIntGov_mode.mat',mode_compute=0,load_mh_file,mode_check,mh_nblocks=5,mh_replic=0, mh_jscale=0.46,filtered_vars) y;    % mode_compute = 0, load_mh_file, and mh_replic = 0 loads previous estimation results.
    
    % options_.mh_conf_sig=0.9

    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'upsilon');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'varphi');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'theta');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'kappa_p');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'kappa_w');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'gamma_p');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'gamma_w');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'kappa_b');

    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_z');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_ksi');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_lam_k');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_c');
    % trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_h');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_i');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_p');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_w');
    trace_plot(options_,M_,estim_params_,'DeepParameter',5,'rho_g');

    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_z');
    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_ksi');
    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_lam_k');
    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_c');
    % trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_h');
    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_i');
    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_p');
    trace_plot(options_,M_,estim_params_,'StructuralShock',5,'e_w');
    
    oo_.posterior_mean
    oo_.posterior_mode
    oo_.posterior_hpdinf
    oo_.posterior_hpdsup

    % shock_decomposition;
end

stoch_simul(order=1,irf=40,nocorr,nomoments,nograph,pruning,replic=3000); 

//*************************************************************************
// Prepare plots
//*************************************************************************

width       = 0.5;  
fsize       = 8;
fsize_alt   = 8;
zero_style  = ':k';
line_style  = 'b-';
period      = 40;   
time        = 1:period;
zero        = time*0;

//*************************************************************************
// Plot a figure with impulse responses to capital quality shock
//*************************************************************************



/*
f1=figure(5);

subplot(3,3,1)
plot(time,oo_.irfs.ksi_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
title('Quality of Capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,2)
plot(time,oo_.irfs.y_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.c_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.i_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.k_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,6)
plot(time,oo_.irfs.q_k_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of Capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,7)
plot(time,oo_.irfs.n_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Net Worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,8)
plot(time,oo_.irfs.phi_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Leverage','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,9)
plot(time,oo_.irfs.Ecs_e_ksi*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit Spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


f2=figure(6);

subplot(3,3,1)
plot(time,oo_.irfs.weight_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Portfolio weight claims','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,2)
plot(time,oo_.irfs.b_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Number of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.q_b_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

% subplot(3,3,4)
% plot(time,oo_.irfs.w_e_ksi*100,line_style,'LineWidth',width)
% hold on, box off
% plot(time,zero,zero_style)
% title('Wages','FontSize',fsize)
% ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.r_n_e_ksi*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.h_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Labor','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,6)
plot(time,oo_.irfs.pi_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Inflation','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)


% subplot(3,3,7)
% plot(time,oo_.irfs.r_d_e_ksi*10000,line_style,'LineWidth',width)
% hold on, box off
% plot(time,zero,zero_style)
% title('Ex-post return on deposits','FontSize',fsize)
% ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
% xlabel('Quarters','FontSize',fsize_alt)


subplot(3,3,7)
plot(time,(oo_.irfs.p_def_e_ksi+p_def_ss)*10000,line_style,'LineWidth',width)
hold on, box off
title('Default probability','FontSize',fsize)
ylabel({'Abs. levle';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,7)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off

subplot(3,3,8)
plot(time,oo_.irfs.Erb_e_ksi*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Return on bonds E[r^b]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,9)
plot(time,oo_.irfs.Erk_e_ksi*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Return on capital E[r^k]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


f3=figure(7);

subplot(3,3,1)
plot(time,oo_.irfs.lambda_b_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Diversion rate govt bonds','FontSize',fsize)
ylabel({'Rel. diff. from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.r_n_e_ksi*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,3,7)
plot(time,oo_.irfs.d_e_ksi*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Deposits','FontSize',fsize)
ylabel({'Rel. diff. from s.s.';'in percent'},'FontSize',fsize_alt)



//*************************************************************************
// Shock to diversion rate lambda_k and lambda_b
//*************************************************************************

f1=figure(10);

subplot(3,3,1)
plot(time,oo_.irfs.lambda_k_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
title('Diversion rate private loans','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,2)
plot(time,oo_.irfs.y_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.c_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.i_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.k_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,6)
plot(time,oo_.irfs.q_k_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of Capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,7)
plot(time,oo_.irfs.n_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Net Worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,8)
plot(time,oo_.irfs.phi_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Leverage','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,9)
plot(time,oo_.irfs.Ecs_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit Spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


f2=figure(11);

subplot(3,3,1)
plot(time,oo_.irfs.weight_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Portfolio weight claims','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,2)
plot(time,oo_.irfs.b_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Number of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.q_b_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.w_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Wages','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.h_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Labor','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,6)
plot(time,oo_.irfs.pi_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Inflation','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)


% subplot(3,3,7)
% plot(time,oo_.irfs.r_d_e_lam_k*10000,line_style,'LineWidth',width)
% hold on, box off
% plot(time,zero,zero_style)
% title('Ex-post return on deposits','FontSize',fsize)
% ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
% xlabel('Quarters','FontSize',fsize_alt)


subplot(3,3,7)
plot(time,(oo_.irfs.p_def_e_lam_k+p_def_ss)*10000,line_style,'LineWidth',width)
hold on, box off
title('Default Probability','FontSize',fsize)
ylabel({'Abs. level.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,3,7)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off

subplot(3,3,8)
plot(time,oo_.irfs.Erb_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Return on bonds E[r^b]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,9)
plot(time,oo_.irfs.Erk_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Return on capital E[r^k]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


f3=figure(12);

subplot(3,3,1)
plot(time,oo_.irfs.lambda_b_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Diversion rate govt bonds','FontSize',fsize)
ylabel({'Rel. diff. from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.r_n_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,3,7)
plot(time,oo_.irfs.d_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Deposits','FontSize',fsize)
ylabel({'Rel. diff. from s.s.';'in percent'},'FontSize',fsize_alt)
*/


if 0    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Financial crisis (shock to lambda_k)

% f21=figure(21);
f21=figure(61);

% subplot(3,2,1)
% plot(time,oo_.irfs.lambda_k_e_lam_k*100,line_style,'LineWidth',width)
% hold on, box off
% title('Diversion rate private loans','FontSize',fsize)
% ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,1)
plot(time,(oo_.irfs.g_e_lam_k*g_ss)/y_ss*100,line_style,'LineWidth',width)
hold on, box off
title('Government spending','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent of s.s. GDP'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.y_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,oo_.irfs.c_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,4)
plot(time,oo_.irfs.i_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

% f22=figure(22);
f22=figure(62);

subplot(3,2,1)
plot(time,oo_.irfs.n_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Net Worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.Ecs_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit Spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,(oo_.irfs.p_def_e_lam_k+p_def_ss)*10000,line_style,'LineWidth',width)
hold on, box off
title('Default Probability','FontSize',fsize)
ylabel({'Abs. level.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,3)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off

subplot(3,2,4)
plot(time,oo_.irfs.q_b_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


% f23=figure(23);
f23=figure(63);

subplot(3,2,1)
plot(time,oo_.irfs.w_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Wages','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.h_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Labor','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,oo_.irfs.r_n_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,4)
plot(time,oo_.irfs.pi_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Inflation','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

else    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Governemnt spending (shock e_a)

% f21=figure(21);
f21=figure(61);

% subplot(3,2,1)
% plot(time,oo_.irfs.lambda_k_e_a*100,line_style,'LineWidth',width)
% hold on, box off
% title('Diversion rate private loans','FontSize',fsize)
% ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,1)
plot(time,(oo_.irfs.g_e_a*g_ss)/y_ss*100,line_style,'LineWidth',width)
hold on, box off
title('Government spending','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent of s.s. GDP'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.y_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,oo_.irfs.c_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,4)
plot(time,oo_.irfs.i_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

% f22=figure(22);
f22=figure(62);

subplot(3,2,1)
plot(time,oo_.irfs.n_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary Net Worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.Ecs_e_a*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit Spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,(oo_.irfs.p_def_e_a+p_def_ss)*10000,line_style,'LineWidth',width)
hold on, box off
title('Default Probability','FontSize',fsize)
ylabel({'Abs. level.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,2,3)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off

subplot(3,2,4)
plot(time,oo_.irfs.q_b_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


% f23=figure(23);
f23=figure(63);

subplot(3,2,1)
plot(time,oo_.irfs.w_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Wages','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,2)
plot(time,oo_.irfs.h_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Labor','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,2,3)
plot(time,oo_.irfs.r_n_e_a*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Nominal interest rate','FontSize',fsize)
ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,2,4)
plot(time,oo_.irfs.pi_e_a*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Inflation','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

end     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




/*
f31=figure(31);

subplot(3,3,1)
plot(time,oo_.irfs.lambda_k_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Diversion rate private loans','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,2)
plot(time,oo_.irfs.g_e_lam_k*g_ss/y_ss*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Government spending','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'as percent s.s. GDP'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.y_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.c_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Consumption','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.i_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,6)
plot(time,oo_.irfs.k_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)


f32=figure(32);

subplot(3,3,1)
plot(time,oo_.irfs.n_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary net worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,2)
plot(time,oo_.irfs.phi_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary leverage','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.Ecs_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.q_k_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of capital','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.q_b_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,6)
plot(time,(oo_.irfs.p_def_e_lam_k+p_def_ss)*10000,line_style,'LineWidth',width)
hold on, box off
title('Default probability','FontSize',fsize)
ylabel({'Abs. level.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,6)
plot(time,time*p_def_ss*10000/time,zero_style)
hold on, box off


f33=figure(33);

if 1
    subplot(3,3,1)
    plot(time,oo_.irfs.g_e_lam_k*g_ss/y_ss*100,line_style,'LineWidth',width)
    hold on, box off
    plot(time,zero,zero_style)
    title('Government spending','FontSize',fsize)
    ylabel({'Rel. \Delta from s.s.';'as percent s.s. GDP'},'FontSize',fsize_alt)
end

if 0
    subplot(3,3,1)
    plot(time,oo_.irfs.n_g_e_lam_k/y_ss*100,line_style,'LineWidth',width)
    hold on, box off
    plot(time,zero,zero_style)
    title('Recapitalization','FontSize',fsize)
    ylabel({'Rel. \Delta from s.s.';'as percent s.s. GDP'},'FontSize',fsize_alt)
end

if 0
    subplot(3,3,1)
    plot(time,oo_.irfs.r_n_e_lam_k*10000,line_style,'LineWidth',width)
    hold on, box off
    plot(time,zero,zero_style)
    title('Nominal interest rate','FontSize',fsize)
    ylabel({'Abs. diff. from s.s.';'in basis pts.'},'FontSize',fsize_alt)
end

subplot(3,3,2)
plot(time,oo_.irfs.n_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Intermediary net worth','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,3)
plot(time,oo_.irfs.i_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Investment','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)

subplot(3,3,4)
plot(time,oo_.irfs.y_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Output','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,5)
plot(time,oo_.irfs.Ecs_e_lam_k*10000,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Credit spread E[r^k-r^d]','FontSize',fsize)
ylabel({'Abs. \Delta from s.s.';'in basis pts.'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)

subplot(3,3,6)
plot(time,oo_.irfs.q_b_e_lam_k*100,line_style,'LineWidth',width)
hold on, box off
plot(time,zero,zero_style)
title('Price of bonds','FontSize',fsize)
ylabel({'Rel. \Delta from s.s.';'in percent'},'FontSize',fsize_alt)
xlabel('Quarters','FontSize',fsize_alt)
*/

if 0    % f21 & f22 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    directory=[pwd '\graphs\papers'];
    filename1=[directory '\lambda_shock_0_03_rho_r_0_8_quarters_25_nopolicy_vs_del_stim_0_05GDP_series1'];
    print(f21,'-dpdf',filename1)
    saveas(f21,filename1,'fig')

    filename2=[directory '\lambda_shock_0_03_rho_r_0_8_quarters_25_nopolicy_vs_del_stim_0_05GDP_series2'];
    print(f22,'-dpdf',filename2)
    saveas(f22,filename2,'fig')
end     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if 0
    directory=[pwd '\graphs\papers'];
    filename1=[directory '\lambda_shock_0_08_rho_r_0_8_quarters_25_nopolicy_vs_del_stim_0_05GDP_series1'];
    print(f31,'-dpdf',filename1)
    saveas(f31,filename1,'fig')

    filename2=[directory '\lambda_shock_0_08_rho_r_0_8_quarters_25_nopolicy_vs_del_stim_0_05GDP_series2'];
    print(f32,'-dpdf',filename2)
    saveas(f32,filename2,'fig')
end

if 0
    directory=[pwd '\graphs\papers'];
    filename3=[directory '\lambda_shock_0_08_rho_r_0_8_quarters_25_nodefault_vs_default_del_stim_0_05GDP_series1'];
    print(f33,'-dpdf',filename3)
    saveas(f33,filename3,'fig')
end

if 0
    directory=[pwd '\graphs\papers'];
    filename3=[directory '\lambda_shock_0_08_rho_r_0_8_quarters_1_vs_25_nodefault_del_stim_0_05GDP_series1'];
    print(f33,'-dpdf',filename3)
    saveas(f33,filename3,'fig')
end

if 0
    directory=[pwd '\graphs\papers'];
    filename3=[directory '\lambda_shock_0_08__default_del_stim_0_05GDP_norecap_vs_taxrecap0_05GDP'];
    print(f33,'-dpdf',filename3)
    saveas(f33,filename3,'fig')
end

if 0
    directory=[pwd '\graphs\papers'];
    filename3=[directory '\default_lambda_shock_0_08_rho_r_0_8_vs_0_999_quarters_25_default_del_stim_0_05GDP_series1'];
    print(f33,'-dpdf',filename3)
    saveas(f33,filename3,'fig')
end

//*************************************************************************
// Compute and save statistics on output response
//*************************************************************************
/*
stoch_simul(order=1,irf=1000,nomoments,nograph,noprint,pruning);
period = 1000;

period = 200; % 40;


if 0    % calculations for level variables---------------------------------

tmp_y           = cumsum(oo_.irfs.y_e_lam_k(1:period));
tmp_g           = cumsum(oo_.irfs.g_e_lam_k(1:period));

stat.cum_y      = tmp_y(end);
stat.cum_g      = tmp_g(end);

for i=1:period, dis_fac(i)=beta^(i-1); end

tmp_y           = cumsum(dis_fac.*oo_.irfs.y_e_lam_k(1:period));
tmp_g           = cumsum(dis_fac.*oo_.irfs.g_e_lam_k(1:period));

stat.dis_cum_y  = tmp_y(end);
stat.dis_cum_g  = tmp_g(end);

v_y_irf         = oo_.irfs.y_e_lam_k(1:period)/y_ss*100;
v_g_irf         = oo_.irfs.g_e_lam_k(1:period)/y_ss*100;

m_irf           = [v_y_irf; v_g_irf];

tmp_y_a         = cumsum(dis_fac.*oo_.irfs.y_e_a(1:period));
tmp_g_a         = cumsum(dis_fac.*oo_.irfs.g_e_a(1:period));
dcmp            = tmp_y_a/tmp_g_a;

disp('The value of the delayed government spending multiplier is equal to')
disp(dcmp)

else    % calculations for log-variables-----------------------------------

tmp_y           = cumsum(oo_.irfs.y_e_lam_k(1:period)*y_ss);
tmp_g           = cumsum(oo_.irfs.g_e_lam_k(1:period)*g_ss);

stat.cum_y      = tmp_y(end);
stat.cum_g      = tmp_g(end);

for i=1:period, dis_fac(i)=beta^(i-1); end

tmp_y           = cumsum(dis_fac.*oo_.irfs.y_e_lam_k(1:period)*y_ss);
tmp_g           = cumsum(dis_fac.*oo_.irfs.g_e_lam_k(1:period)*g_ss);

stat.dis_cum_y  = tmp_y(end);
stat.dis_cum_g  = tmp_g(end);

v_y_irf         = oo_.irfs.y_e_lam_k(1:period)*100;
v_g_irf         = oo_.irfs.g_e_lam_k(1:period)*g_ss/y_ss*100;

m_irf           = [v_y_irf; v_g_irf];

tmp_y_a         = cumsum(dis_fac.*oo_.irfs.y_e_a(1:period)*y_ss);
tmp_g_a         = cumsum(dis_fac.*oo_.irfs.g_e_a(1:period)*g_ss);
dcmp            = tmp_y_a/tmp_g_a;

disp('The value of the delayed government spending multiplier is equal to')
disp(dcmp)

end     %------------------------------------------------------------------


if ((varzeta1 == 0) && (varzeta2 == 0))    % the file saves only when there is lambda-shock
    savefile1 = 'transfer_nopolicy.mat';
    savefile2 = 'irf_nopolicy.mat';
elseif(varzeta2 == 0)
    savefile1 = 'transfer_imm_stim.mat';
    savefile2 = 'irf_imm_stim.mat';
else
    savefile1 = 'transfer_del_stim.mat';
    savefile2 = 'irf_del_stim.mat';
end

save(savefile1,'stat');
save(savefile2,'m_irf');
*/
