% FinIntGovDefMain.m
% Financial intermediary model with defaulting government of Kirhcner
% This is the main file that solves the FinIntGov model.

%--------------------------------------------------------------------------
% Financial intermediary model with gov't bond pricing and elimination of 
% portfolio costs. Government bonds are modelled as in Woodford (1998, 2001)
% New default mechanism
%--------------------------------------------------------------------------

% Christiaan van der Kwaak
% 15.04.2016

% Update February 2016:  
% - inlcusion of time-varying diversion rates lambda_k and lambda_b
% - inclusion of (partial) price-indexation for firms that are not allowed 
% to change prices

% Update April 2016. New default mechanism that we can solve at first order,
% see "default_modeling_2016_04_06.pdf", where we follow Schabert and van 
% Wijnbergen (2014) and Corsetti et al. (2013).

% Update 11 April 2016. We include wage-stickiness into the model a la 
% Ferrero, Eggertsson and Raffo (2014) "Can Structural Reforms Help Europe"
% JME paper.

% Update March 2018: include an investment adjustment shock and update of 
% the Bayesian estimation

% Update April 2018: 
% - eliminate the investment adjustment shock of March 2018.
% - introduction of subjective discount factor shock.
% - calibration of depreciation parameter, no more targeting of steady state 
% investment-output ratio.
% - change of new bankers' net worth provision from linear in previous period 
% assets to linear in previous period net worth.

% Second update April 2018:
% - replacement of Calvo-pricing by Rotemberg-pricing

clear all
clc

% disp('FIRST RETRIEVE THE POSTERIOR-DISTRIBUTIONS OF YOUR CALCULATION YESTERDAY')
% return;

%--------------------------------------------------------------------------
% 1. Parameters
%--------------------------------------------------------------------------

par.T_tot = 1250;                       % length of simulation
par.T0 = 1000;                          % start of sample
par.TI = 40;                            % length of simulation IRF

par.tol     = 1E-16;                    % tolerance level for convergence
par.spain   = 1;                        % parameter specifying whether or not model is calibrated on Spanish economy. par.spain = 1 indicates model is calibrated on Spanish economy, otherwise not
par.calibration = 3;                    % calibration is a parameter that determines the calibration of the default function. 
                                        % Calibration = 1 targets the
                                        % steady state default probability
                                        % and the first order derivative of
                                        % the default probability at the
                                        % steady state, and finds the
                                        % accompanying alpha_b and beta_b
                                        % of the betacdf
                                        % Calibration = 2 takes alpha_b and
                                        % beta_b from "Calibration = 1",
                                        % and calculates the accompanying
                                        % steady state default probability.
                                        % Calibration = 3 sets the default
                                        % probability at zero, accompanying
                                        % adjustment in mod.file needed!
                                        % Calibration = 4 follows
                                        % Corsetti, Kuester, Meier and Mueller, EJ (2013) paper

% households
par.beta    = 0.990;                    % discount factor
par.upsilon = 0.815;                    % degree of habit formation
par.dis_lab = 3.409;                    % disutility of labor
par.varphi  = 0.276;                    % inverse Frisch elasticity of labor supply

% financial intermediaries
par.tb      = 36;                       % average lifetime bankers in quarters
par.Gamma   = 0.0025;                   % steady state spread between loans/bonds and deposits
par.lambda_b_k = 0.5;                   % ratio of diversion rate of government bonds vs. diversion rate of private loans

% goods producing firms
par.alpha   = 0.330;                    % share of effective capital in production
par.delta   = 0.025;                    % depreciation parameter
par.eps_p   = 4.176;                    % elasticity of substitution
par.psi_p   = 0.779;                    % Calvo probability of keeping prices fixed
par.gamma_p = 1;                        % inflation indexation for firms that cannot change prices in a given period
par.kappa_p = ((par.eps_p-1)*par.psi_p)/((1-par.psi_p)*(1-par.beta*par.psi_p));     % Rotemberg price-adjustment coefficient

% wage-stickiness parameters
par.eps_w   = 7.758;                    % elasticity of susbtitution between labor supplied by households
par.psi_w   = 0.457;                    % Calvo probability of keeping nominal wages fixed
par.gamma_w = 0.961;                    % wage indexation for households that cannot change wages in a given period
par.kappa_w = par.kappa_p;              % Rotemberg wage-adjustment coefficient

% capital producing firms
par.gamma   = 1.728;                    % investment adjustment cost parameter

% default parameters
par.Phi_b  = 0.050;                      % default elasticity with respect to government debt

% aggregate ratios
%par.i_y = 0.2;                          % steady state ratio of investment over output
par.g_y = 0.2;                          % steady state ratio of government spending over output
par.qb_y = 2.4;                         % steady state ratio of government liabilities (q_t^b*b_t) over quarterly output
par.qb_max_y = 3.6;                     % steady state level of maximum government liabilities (q_t^b*b_t^max)
par.tau_y_max = 0.25;                   % steady state ratio maximum level of taxes over output

% policy parameters
par.kappa_b = 0.050;                    % government debt feedback on taxes
par.kappa_g = 0.000;                    % government consumption feedback on taxes
par.kappa_n = 0.000;                    % government financial support feedback on taxes
par.kappa_pi= 1.500;                    % inflation feedback on nominal interest rate
par.kappa_y = 0.125;                    % output feedback on nominal interest rate
par.kappa_ksi = 0;                      % feedback of capital quality shock on nominal interest rate (capital quality shock of 5 percent induces reduction of 1 percent in interest rate)
par.kappa_e_ksi = 0;                    % feedback of (delayed) capital quality shock on deposit/equity swap

par.rho_z    = 0.95;                    % persistence parameter on productivity shocks
par.rho_ksi  = 0.66;                    % persistence parameter on capital quality shocks
par.rho_g    = 0.8;                     % persistence parameter of government spending
par.rho_b    = 0.8;                     % persistence parameter of maximum level of debt
par.rho_r    = 0.4;                     % persistence parameter of nominal interest rate
par.rho_lam_k  = 0.7;                   % persistence parameter on diversion rate private loans
par.rho_c    = 0.9;                     % persistence parameter of consumption preference shock
par.rho_h    = 0.9;                     % persistence parameter of labor preference shock
par.rho_i    = 0.9;                     % persistence parameter of investment adjustment costs shock
par.rho_p    = 0.9;                     % persistence parameter of shock to elasticity of substitution of retail goods prices
par.rho_w    = 0.9;                     % persistence parameter of shock to elasticity of substitution of unions for wages

par.spending_n = 0.2;                   % percentage of steady state GDP that is used for recapitalization of financial intermediaries
par.spending_g = 0.05;                  % percentage of steady state GDP that is used for fiscal stimulus

par.zeta1     = 0;                      % multiplier of immediate stimulus spending in response to capital quality shock
par.zeta2     = 0;                      % multiplier of delayed stimulus spending 4 quarters after initial capital quality shock
par.varzeta1  = 0;                      % multiplier of immediate stimulus spending in response to diversion rate shock
par.varzeta2  = 0;                      % multiplier of delayed stimulus spending 4 quarters after initial diversion rate shock
par.varkappa1 = 0;                      % multiplier to immediate government net worth provision after shock in capital quality
par.varkappa2 = 0;                      % multiplier to delayed government net worth provision 4 quarters after initial shock in capital quality
par.varlambda1 = 0;                     % multiplier to immediate government net worth provision after shock in diversion rate private loans
par.varlambda2 = 0;                     % multiplier to delayed government net worth provision 4 quarters after initial shock in diversion rate private loans
par.vartheta1 = 0;                      % penalty rate with which financial support has to be repaid if repayment occurs 4 quarters after loans have been provided
par.vartheta2 = 0;                      % penalty rate with which financial support has to be repaid if repayment occurs 16 quarters after loans have been provided
par.kappa_esm = 1;                      % share of recapitalisation financed by government through Sweder mechanism
par.alpha_esm = 0;                      % multiplier to net government net worth provision financed by ESM funds through my mechanism

par.lagstate = 16;                      % number of lags for the state variable with the largest number of lags
par.lag      = 0;                       % lag wtih which stimulus spending/capital injection is implemented
par.lag_pb   = 0;                       % lag wtih which capital injection is paid back

% shocks
par.sigshock_z   = 0.010;               % standard deviation productivity shock
par.sigshock_ksi = 0.050;               % standard deviation capital quality shock
par.sigshock_u   = 0.050;               % standard deviation surprise government spending shock
par.sigshock_a   = 0.050;               % standard deviation pre-announced government spending shock
par.sigshock_b   = 0.050;               % standard deviation maximum debt level shock
par.sigshock_r   = 0.0025;              % standard deviation interest rate shock
par.sigshock_lam_k = 0.05;              % standard deviation shock to diversion rate
par.sigshock_c   = 0.010;               % standard deviation consumption preference shock
par.sigshock_h   = 0.010;               % standard deviation labor preference shock
par.sigshock_i   = 0.010;               % standard deviation investment adjustment costs shock
par.sigshock_p   = 0.010;               % standard deviation shock to elasticity of substitution of retail goods prices
par.sigshock_w   = 0.010;               % standard deviation shock to elasticity of substitution of unions for wages
    
% calibration targets
par.tb          = 24;                   % average lifetime bankers in quarters
par.Gamma       = 0.0025;               % steady state spread between loans/bonds and deposits
par.lambda_b_k  = 0.5;                  % ratio of diversion rate of government bonds vs. diversion rate of private loans
par.lambda_e_k  = 0;                    % ratio of diversion rate of external bonds vs. diversion rate of private loans
par.h_ss        = 1/3;                  % steady state value of labor
par.pi_ss       = 1.005;                % steady state value for the inflation rate (2 percent annual inflation)
par.q_k_ss      = 1;                    % steady state value of capital price
par.z_ss        = 1;                    % steady state value of productivity
par.ksi_ss      = 1;                    % steady state value of capital quality variable
par.c_shock_ss  = 1;                    % steady state value of consumption preference shock
par.h_shock_ss  = 1;                    % steady state value of labor preference shock
par.i_shock_ss  = 1;                    % steady state value of investment adjustment costs shock
par.phi_ss      = 4;                    % steady state leverage ratio
par.r_c         = 0.04;                 % coupon payment in real terms on government consols
par.quarters    = 40;                   % effective maturity of long-term government bonds
par.vartheta_cf = 0.5;                  % haircut on the cashflow payment r_c
par.vartheta_p  = 0.5;                  % haircut on the principal repayment
par.p_def_ss    = 0.005;                % steady state default probability
par.p_def_deriv_ss = 0.05;               % steady state derivative of default probability p_def
par.alpha_b_0   = 1;                    % initial guess alpha_b
par.beta_b_0    = 1;                    % initial guess beta_b
par.n_g_ss      = 0;                    % steady state value of government assistance to financial sector
par.n_g_til_ss  = 0;                    % steady state value of payback of financial assistance from financial sector to government
par.aa_ss       = 0;                    % steady state value of coefficient relating government support and previous period net worth of individual intermediaries
par.bb_ss       = 0;                    % steady state value of tax rate on previous period net worth

% Spain calibration
if (par.spain==1)
    % households
    par.beta    = 0.990;                    % discount factor
    par.upsilon = 0.5562; % 0.847;                    % degree of habit formation
    par.varphi  = 1.3395; % 1/1.835;                  % inverse Frisch elasticity of labor supply
    

    % goods producing firms
    par.alpha   = 0.362;                    % share of effective capital in production
    par.delta   = 0.0355; % 0.025;                    % depreciation parameter    
    par.eps_p   = 8.577;                    % elasticity of substitution
    par.psi_p   = 0.8; % 0.850;                    % Calvo probability of keeping prices fixed
    par.gamma_p = 0.3734; % 0.004;                        % inflation indexation for firms that cannot change prices in a given period
    % par.kappa_p = ((par.eps_p-1)*par.psi_p)/((1-par.psi_p)*(1-par.beta*par.psi_p));     % Rotemberg price-adjustment coefficient
    par.kappa_p = 47.9690;     % Rotemberg price-adjustment coefficient
    
    % wage-stickiness parameters
    par.eps_w   = 7.758;                   % elasticity of susbtitution between labor supplied by households
    par.psi_w   = 0.457;                    % Calvo probability of keeping nominal wages fixed
    par.gamma_w = 0.0850; % 0.961;                    % wage indexation for households that cannot change wages in a given period
    % par.kappa_w = par.kappa_p;              % Rotemberg wage-adjustment coefficient
    par.kappa_w = 19.4490;              % Rotemberg wage-adjustment coefficient
    
    % capital producing firms
    par.gamma   = 0.7609; % 4.0177;                    % investment adjustment cost parameter
    
    % aggregate ratios
%    par.i_y = 0.226;                        % steady state ratio of investment over output
    par.g_y = 0.178;                        % steady state ratio of government spending over output
    par.qb_y = 3.2;                       % steady state ratio of government liabilities (q_t^b*b_t) over quarterly output
    par.qb_max_y = 2.4;                     % steady state level of maximum government liabilities (q_t^b*b_t^max) over quarterly output

    % policy parameters
    par.kappa_b = 0.0482; % 0.0507;                % government debt feedback on taxes
    par.kappa_g = 0.000;                    % government consumption feedback on taxes
    par.kappa_n = 0.000;                    % government financial support feedback on taxes
    par.kappa_pi= 1.700;                    % inflation feedback on nominal interest rate
    par.kappa_y = 0.125;                    % output feedback on nominal interest rate
    par.kappa_ksi = 0;                      % feedback of capital quality shock on nominal interest rate (capital quality shock of 5 percent induces reduction of 1 percent in interest rate)
    par.kappa_e_ksi = 0;                    % feedback of (delayed) capital quality shock on deposit/equity swap
    
    par.rho_z    = 0.7746; % 0.9848;                     % persistence parameter on productivity shocks
    par.rho_ksi  = 0.7632; % 0.66;                    % persistence parameter on capital quality shocks
    par.rho_g    = 0.9741; % 0.9983;                  % persistence parameter of government spending
    par.rho_r    = 0.8;                     % persistence parameter of nominal interest rate
    par.rho_lam_k  = 0.7; % 0.8239; % 0.7;                   % persistence parameter on diversion rate private loans
    par.rho_c    = 0.9225; % 0.9;                     % persistence parameter of consumption preference shock
    par.rho_h    = 0.9;                     % persistence parameter of labor preference shock
    par.rho_i    = 0.7197; % 0.9;                     % persistence parameter of investment adjustment costs shock
    par.rho_p    = 0.6634; % 0.9;                     % persistence parameter of shock to elasticity of substitution of retail goods prices
    par.rho_w    = 0.4291; % 0.9;                     % persistence parameter of shock to elasticity of substitution of unions for wages

    
    par.spending_n = 0.05;                   % percentage of steady state GDP that is used for recapitalization of financial intermediaries
    par.spending_g = 0.05;                  % percentage of steady state GDP that is used for fiscal stimulus
    
    par.zeta1     = 0;                      % multiplier of immediate stimulus spending in response to capital quality shock
    par.zeta2     = 0;                      % multiplier of delayed stimulus spending 4 quarters after initial capital quality shock
    par.varzeta1  = 0;                      % multiplier of immediate stimulus spending in response to diversion rate shock
    par.varzeta2  = 0;                      % multiplier of delayed stimulus spending 4 quarters after initial diversion rate shock
    par.varkappa1 = 0;                      % multiplier to immediate government net worth provision after shock in capital quality
    par.varkappa2 = 0;                      % multiplier to delayed government net worth provision 4 quarters after initial shock in capital quality
    par.varlambda1 = 0;                     % multiplier to immediate government net worth provision after shock in diversion rate private loans
    par.varlambda2 = 0;                     % multiplier to delayed government net worth provision 4 quarters after initial shock in diversion rate private loans
    par.vartheta1 = 0;                      % penalty rate with which financial support has to be repaid if repayment occurs 4 quarters after loans have been provided
    par.vartheta2 = 0;                      % penalty rate with which financial support has to be repaid if repayment occurs 16 quarters after loans have been provided
    
    par.lagstate = 16;                      % number of lags for the state variable with the largest number of lags
    
    % shocks
    par.sigshock_z   = 0.0055; % 0.0234;               % standard deviation productivity shock
    par.sigshock_ksi = 0.0025; % 0.050;               % standard deviation capital quality shock
    par.sigshock_u   = 0.050;               % standard deviation surprise government spending shock
    par.sigshock_a   = 0.0289; % 0.0343;          % standard deviation pre-announced government spending shock
    par.sigshock_r   = 0.0025;              % standard deviation interest rate shock
    par.sigshock_lam_k = 0.03; % 0.0035; % 0.08;              % standard deviation shock to diversion rate
    par.sigshock_c   = 0.0276; % 0.010;               % standard deviation consumption preference shock
    par.sigshock_h   = 0.010;               % standard deviation labor preference shock
    par.sigshock_i   = 0.0085; % 0.010;               % standard deviation investment adjustment costs shock
    par.sigshock_p   = 0.1078; % 0.010;               % standard deviation shock to elasticity of substitution of retail goods prices
    par.sigshock_w   = 0.6324; % 0.010;               % standard deviation shock to elasticity of substitution of unions for wages
    
    % calibration targets
    par.tb              = 24;               % average lifetime bankers in quarters
    par.Gamma           = 0.0025; % 0.0028; % 0.0047; % steady state spread between loans/bonds and deposits. 0.0025 is average spread during 2000-2007, where deposit rate is 3M-Euribor. 0.0028 is average spread during 2000-2010
    par.lambda_b_k      = 1; % 0.5;              % ratio of diversion rate of government bonds vs. diversion rate of private loans. Set to one after calculation of the spread between govt bond yields and real policy rate is 0.0030 over period 1998-2007
    par.h_ss            = 1/3;              % steady state value of labor
    par.pi_ss           = 1.005;            % steady state value for the inflation rate (2 percent annual inflation)
    par.q_k_ss          = 1;                % steady state value of capital price
    par.z_ss            = 1;                % steady state value of productivity
    par.ksi_ss          = 1;                % steady state value of capital quality variable
    par.c_shock_ss      = 1;                % steady state value of consumption preference shock
    par.h_shock_ss      = 1;                % steady state value of labor preference shock
    par.i_shock_ss      = 1;                % steady state value of investment adjustment costs shock
    par.x_ss            = 1;                % steady state growth of assets
    par.phi_ss          = 5.1;              % steady state leverage ratio
    par.r_c             = 0.041;            % coupon payment in real terms on government consols
    par.quarters        = 25; % 40;               % effective maturity of long-term government bonds
    par.vartheta_cf     = 0.5;              % haircut on the cashflow payment r_c
    par.vartheta_p      = 0.5;              % haircut on the principal repayment
    par.p_def_ss        = 0.005;            % steady state default probability
    par.p_def_deriv_ss  = 0.2;             % steady state derivative of default probability p_def
    par.alpha_b_0       = 1;                % initial guess alpha_b
    par.beta_b_0        = 1;                % initial guess beta_b
    par.n_g_ss          = 0;                % steady state value of government assistance to financial sector
    par.n_g_til_ss      = 0;                % steady state value of payback of financial assistance from financial sector to government
    par.aa_ss           = 0;                % steady state value of coefficient relating government support and previous period net worth of individual intermediaries
    par.bb_ss           = 0;                % steady state value of tax rate on previous period net worth

else
end

if 0
   load quarters_parameter;
   par.quarters         = quarters;         % effective maturity of long-term government bonds
   disp('The value of quarters is equal to')
   disp(quarters)   
else
end

if 0
   load Delta_parameter;
   par.lambda_b_k         = lambda_b_k;     % ratio of diversion rate of government bonds vs. diversion rate of private loans
   disp('The value of the relative diversion ratios lambda is equal to')
   disp(lambda_b_k)   
else
end

options = optimset('TolFun',par.tol);

par.TL       = par.TI + par.lagstate;

% setting the figure settings for plotting
lineshape = '-';
color     = 'b';
width     = 0.5;

%%
%--------------------------------------------------------------------------
% 2. Calculation of steady state values and calibrated parameters
%--------------------------------------------------------------------------

% Financial steady state values and parameters

par.rd_ss                   = 1/par.beta-1;                 % steady state value for the net return on the deposits
par.R_d_ss                  = 1+par.rd_ss;                  % steady state value for the gross return on the deposits
par.pi_adj_ss               = par.pi_ss^(par.gamma_p);      % steady state value inflation indexation
par.pi_star_ss              = 1;                            % steady state value for the inflation rate (variable redundant for Rotemberg-pricing)
par.pi_bar                  = par.pi_ss;                    % target value for the inflation rate
% par.rn_ss                   = (1+par.rd_ss)*par.pi_ss-1;    % steady state value for the nominal interest rate
par.rn_ss                   = (1+par.rd_ss)*par.pi_ss-1;    % steady state value for the net nominal interest rate
par.R_n_ss                  = 1+par.rn_ss;                  % steady state value for the gross nominal interest rate
par.Delta_ss                = 1;                            % steady state value of Delta (variable redundant for Rotemberg-pricing)
% par.theta                   = (par.tb-1)/par.tb;            % survival rate of bankers
par.theta                   = 0.9750;            % survival rate of bankers
par.rk_ss                   = par.rd_ss+par.Gamma;          % steady state value of net return on loans
par.R_k_ss                  = 1+par.rk_ss;                  % steady state value of gross return on loans
par.Erk_ss                  = par.rk_ss;                    % steady state value of expected interest rate on loans
par.Ecs_ss                  = par.Gamma;                    % steady state value of expected credit rate spread
par.xk_ss                   = par.x_ss;                     % steady state growth of private loans
par.xb_ss                   = par.x_ss;                     % steady state growth of government bonds

par.omega_ss                = par.pi_ss;                    % steady state value for the wage-inflation rate (2 percent annual wage-inflation)
par.omega_adj_ss            = par.omega_ss^(par.gamma_w);   % steady state wage-indexation
par.omega_new_ss            = 1;                            % steady state value for the wage-inflation rate (variable redundant for Rotemberg-pricing)
par.Delta_w_ss              = 1;                            % steady state wage-dispersion (variable redundant for Rotemberg-pricing)


% Production steady state values and parameters
par.m_ss                    = (par.eps_p-1)/par.eps_p;      % steady state value of relative price of intermediate goods with respect to general price level
par.w_ss                    = (par.alpha^(par.alpha)*(1-par.alpha)^(1-par.alpha)*par.m_ss/(par.rk_ss+par.delta)^(par.alpha))^(1/(1-par.alpha));     % steady state value of wage rate
par.kh_ss                   = (par.alpha/(1-par.alpha))*par.w_ss/(par.rk_ss+par.delta);                                                             % steady state value of capital-labor ratio

par.k_ss                    = par.kh_ss*par.h_ss;           % steady state value of capital
par.y_ss                    = par.z_ss*(par.ksi_ss*par.k_ss)^(par.alpha)*par.h_ss^(1-par.alpha);            % steady state value of output
par.i_ss                    = par.delta*par.k_ss;           % steady state value of investment
par.g_ss                    = par.g_y*par.y_ss;             % steady state value of government spending
par.g_til_ss                = par.g_ss;                     % steady state value of regular government spending
par.c_ss                    = par.y_ss-par.i_ss-par.g_ss;   % steady state value of consumption
par.c_y                     = par.c_ss/par.y_ss;            % steady state ratio of consumption over output
par.i_y                     = par.i_ss/par.y_ss;            % steady state ratio of investment over output
par.lambda_ss               = (1-par.beta*par.upsilon)/((1-par.upsilon)*par.c_ss);          % steady state value of marginal utility of consumption
par.Ksi_1_ss                = 1;                            % steady state value of Ksi_1 (variable redundant for Rotemberg-pricing)
par.Ksi_2_ss                = 1;                            % steady state value of Ksi_2 (variable redundant for Rotemberg-pricing)
par.Ksi_1_w_ss              = 1;                            % steady state value of Ksi_1_w (variable redundant for Rotemberg-pricing)
par.Ksi_2_w_ss              = 1;                            % steady state value of Ksi_2_w (variable redundant for Rotemberg-pricing)
par.dis_lab                 = ((par.eps_w-1)/par.eps_w)*par.lambda_ss*par.w_ss/(par.h_shock_ss*par.h_ss^par.varphi);      % disutility of labor constant


% sovereign debt variables
par.qb_ss                   = par.qb_y*par.y_ss;            % steady state level of government liabilities (q_t^b*b_t)
par.qb_max_ss               = par.qb_max_y*par.y_ss;        % steady state level of maximum government liabilities (q_t^b*b_t^max)

%--------------------------------------------------------------------------
if (par.calibration == 1)
    % We take the steady state default probability and the first order
    % derivative at the steady state default probability as given.
    % We find coefficients alpha_b and beta_b of the betacdf by targeting 
    % the steady state default probability and its first derivative
    x0                          = [par.alpha_b_0;par.beta_b_0];
    x                           = fsolve(@(x)Betacdf_parameters(x,par),x0,options);
    par.alpha_b                 = x(1);                         % alpha_b coefficient for the betacdf
    par.beta_b                  = x(2);                         % beta_b coefficient for the betacdf
    
    disp('The parameter values for alpha_b and beta_b are given by:')
    disp(par.alpha_b)
    disp(par.beta_b)
    
    % CHECK
    
    p_def_ss                    = betacdf(par.qb_ss/(4*par.y_ss*par.qb_max_ss),par.alpha_b,par.beta_b);
    p_def_deriv_ss              = betapdf(par.qb_ss/(4*par.y_ss*par.qb_max_ss),par.alpha_b,par.beta_b);
    
    dif2                        = par.p_def_ss-p_def_ss;
    dif3                        = par.p_def_deriv_ss-p_def_deriv_ss;
    disp('The difference between the targeted steady state default probability and the implied default probability from the found parameters of the beta-distribution')
    disp(dif2)
    disp('The difference between the targeted first derivative of the steady state default probability and the implied first derivative of the default probability from the found parameters of the beta-distribution')
    disp(dif3)
    save betacdf_coefficients x
elseif (par.calibration == 2)   % par.calibration = 2
    % In this case we take the coefficients alpha_b and beta_b of the
    % betacdf as given, and calculate the accompanying steady state default
    % probability
    load betacdf_coefficients
    par.alpha_b                 = x(1);                         % alpha_b coefficient for the betacdf
    par.beta_b                  = x(2);                         % beta_b coefficient for the betacdf
    par.p_def_ss                = betacdf(par.qb_ss/(4*par.y_ss*par.qb_max_ss),par.alpha_b,par.beta_b);
elseif (par.calibration == 3)   % par.calibration = 3
    % We set the default probability to zero and set p_def = 0 in the
    % mod-file. No coefficients need to be calculated
    p_def_ss                    = par.p_def_ss;                 % store the steady state default probability in p_def_ss for calculation of par.theta_bar below
    par.alpha_b                 = 1;                            % alpha_b coefficient for the betacdf, mod-file is asking for it even though it won't be used in the model
    par.beta_b                  = 1;                            % beta_b coefficient for the betacdf, mod-file is asking for it even though it won't be used in the model
    par.p_def_ss                = 0;    
else                               % par.calibration = 4
    % We follow Corsetti, Kuester, Meier and Mueller, EJ (2013)
    par.alpha_b                 = 3.70;                            % alpha_b coefficient for the betacdf, mod-file is asking for it even though it won't be used in the model. See Corsetti, Kuester, Meier, Muller, EJ (2013)
    par.beta_b                  = 0.54;                            % beta_b coefficient for the betacdf, mod-file is asking for it even though it won't be used in the model. See Corsetti, Kuester, Meier, Muller, EJ (2013)
    par.p_def_ss                = betacdf(par.qb_ss/(4*par.y_ss*par.qb_max_ss),par.alpha_b,par.beta_b);    % Follows automatically from Corsetti, Kuester, Meier, Muller, EJ (2013)
    par.p_def_deriv_ss          = betapdf(par.qb_ss/(4*par.y_ss*par.qb_max_ss),par.alpha_b,par.beta_b);    % Follows automatically from Corsetti, Kuester, Meier, Muller, EJ (2013)
end

%--------------------------------------------------------------------------

par.rho                     = 1/par.quarters;                                               % maturity structure parameter. Expected life of debt is equal to 1/par.rho
par.q_b_ss                  = (1-par.p_def_ss*par.vartheta_cf)*par.r_c/((1+par.rd_ss+par.lambda_b_k*(par.rk_ss-par.rd_ss))*par.pi_ss-(1-par.p_def_ss*par.vartheta_p)*(1-par.rho));      % steady state bond price
par.rb_ss                   = (par.r_c+(1-par.rho)*par.q_b_ss)/(par.pi_ss*par.q_b_ss)-1;    % steady state net return on government consols before default
par.R_b_ss                  = 1+par.rb_ss;                                                  % steady state gross return on government consols before default
par.Erb_ss                  = par.rb_ss;                                                    % steady state expected return on government consols before default
par.tau_ss                  = par.g_ss+par.rb_ss*par.qb_ss+par.n_g_ss-par.n_g_til_ss;       % steady state level of lump sum taxes
par.b_ss                    = par.qb_ss/par.q_b_ss;                                         % steady state number of government bonds
par.b_max_ss                = par.qb_max_ss/par.q_b_ss;                                     % steady state maximum number of government bonds

% % % % % Plotting the betacdf-function
% % % % b = [1.5:0.01:5];
% % % % y = betacdf(b/(4*par.y_ss*par.b_max_ss),par.alpha_b,par.beta_b);
% % % % z = betapdf(b/(4*par.y_ss*par.b_max_ss),par.alpha_b,par.beta_b);
% % % % figure(1)
% % % % plot(b,y)
% % % % figure(2)
% % % % plot(b,z)

% Financial variables continued
par.s_k_ss                  = par.k_ss;                                                     % steady state value of loans to production sector
par.s_b_ss                  = par.b_ss;                                                     % steady state value of loans to government
par.p_ss                    = par.q_k_ss*par.s_k_ss+par.q_b_ss*par.s_b_ss;                  % steady state value of the assets of the financial intermediaries                                     
par.weight_ss               = (par.q_k_ss*par.s_k_ss)/par.p_ss;                             % steady state value of share of assets invested in loans to production sector
par.rp_ss                   = (1+par.rk_ss)*par.weight_ss+(1+par.rb_ss)*(1-par.weight_ss)-1;% steady state value of interest rate on portfolio
par.Erp_ss                  = par.rp_ss;                                                    % steady state value of expected portfolio return
par.n_ss                    = (par.q_k_ss*par.s_k_ss+par.lambda_b_k*par.q_b_ss*par.s_b_ss)/par.phi_ss;      % steady state value of net worth banks
par.d_ss                    = par.p_ss-par.n_ss;                                            % steady state value of deposits of banks

par.eta_ss                  = par.beta*(1-par.theta)*(1+par.rd_ss)/(1-par.beta*par.theta*((1+par.rd_ss)+par.Gamma*par.phi_ss));         % steady state values eta
par.nu_k_ss                 = (par.Gamma/(1+par.rd_ss))*par.eta_ss;                                                                     % steady state values nu_k
par.sdf_ss                  = par.beta*(1-par.theta+par.theta*(par.eta_ss+par.nu_k_ss*par.phi_ss));                                     % steady state value of stochastic discount factor
nu_k_ss                     = par.sdf_ss*(par.rk_ss-par.rd_ss);
par.nu_b_ss                 = par.lambda_b_k*par.nu_k_ss;                                                                               % steady state values nu_b
nu_b_ss                     = par.sdf_ss*(par.rb_ss-par.rd_ss-par.p_def_ss*((par.vartheta_cf*par.r_c+par.vartheta_p*(1-par.rho)*par.q_b_ss)/(par.pi_ss*par.q_b_ss)));

dif4                        = par.nu_k_ss-nu_k_ss;
disp('The difference between the 2 ways of calculating the shadow value of private loans is equal to:');
disp(dif4);

dif5                        = par.nu_b_ss-nu_b_ss;
disp('The difference between the 2 ways of calculating the shadow value of government bonds is equal to:');
disp(dif5);

par.lambda_k_ss             = par.nu_k_ss+par.eta_ss/par.phi_ss;                                                                        % calibrated parameter value for fraction of private loans banker can divert
par.lambda_b_ss             = par.lambda_b_k*par.lambda_k_ss;                                                                           % calibrated parameter value for fraction of government bonds banker can divert
par.mu_ss                   = par.nu_k_ss/(par.lambda_k_ss-par.nu_k_ss);                                                                % steady state value shadow value of bank balance sheet constraint
% par.chi                     = (par.n_ss-par.theta*((par.rk_ss-par.rd_ss)*(par.q_k_ss*par.s_k_ss)+(par.rb_ss-par.rd_ss)*(par.q_b_ss*par.s_b_ss)+(1+par.rd_ss)*par.n_ss))/par.p_ss;       % fraction of net worth that goes to starting bankers
par.chi                     = (par.n_ss-par.theta*((par.rk_ss-par.rd_ss)*(par.q_k_ss*par.s_k_ss)+(par.rb_ss-par.rd_ss)*(par.q_b_ss*par.s_b_ss)+(1+par.rd_ss)*par.n_ss))/par.n_ss;       % fraction of net worth that goes to starting bankers
par.welf_ss                 = (log(par.c_ss-par.upsilon*par.c_ss)-par.h_shock_ss*par.dis_lab*par.h_ss^(1+par.varphi)/(1+par.varphi))/(1-par.beta);     % steady state value of welfare

par.theta_bar               = 1/(par.Gamma*par.phi_ss+p_def_ss*((par.vartheta_cf/(1-p_def_ss*par.vartheta_cf))*(1+par.rd_ss+par.lambda_b_k*par.Gamma)-par.vartheta_cf*(1-par.rho)/par.pi_ss+par.vartheta_p*(1-par.rho)/par.pi_ss)*(par.qb_ss*par.phi_ss)/(par.q_k_ss*par.s_k_ss+par.lambda_b_k*par.qb_ss)+1+par.rd_ss);     % par.theta_bar is upper bound of theta such that par.chi is larger than zero, even when sovereign default risk is included

% Government crisis policy ------------------------------------------------
% par.zeta1     = -par.spending_g*par.y_ss/par.sigshock_ksi;
% par.zeta2     = -par.spending_g*par.y_ss/par.sigshock_ksi;
% par.varzeta1  = par.spending_g*par.y_ss/(par.sigshock_lam_k*par.lambda_k_ss);
% par.varzeta2  = par.spending_g*par.y_ss/(par.sigshock_lam_k*par.lambda_k_ss);
% par.varkappa1 = par.spending_n*par.y_ss/(par.sigshock_ksi*par.n_ss);
% par.varkappa2 = par.spending_n*par.y_ss/(par.sigshock_ksi*par.n_ss);
% par.varlambda1 = par.spending_n*par.y_ss/(par.sigshock_lam_k*par.lambda_k_ss*par.n_ss);
% par.varlambda2 = par.spending_n*par.y_ss/(par.sigshock_lam_k*par.lambda_k_ss*par.n_ss);
% par.vartheta1 = 0;
% par.vartheta2 = 1;

if 0
   load del_stim_parameter;
   par.varzeta2 = par.spending_g*par.y_ss/(par.sigshock_lam_k*par.lambda_k_ss)*ds;       % parameter governing delayed Keynesian stimulus
   disp('The value of ds is equal to')
   disp(ds)
else
end

disp(par)

% return;
%%
%--------------------------------------------------------------------------
% 3. Generate innovations
%--------------------------------------------------------------------------

randn('seed',20100807)
innovations = randn(par.T_tot,1);     % defining innovation series

%%
%--------------------------------------------------------------------------
% 4.Solve model with Dynare
%--------------------------------------------------------------------------

% LL: variable that indicates whether the mod-file with the nonlinear FOC's
% or the loglinearized FOC's is being used. LL = 1 corresponds to the
% mod-file with the nonlinear FOC's, while LL = 2 corresponds to the
% mod-file with the loglinearized FOC's
LL = 1;

save parametervalues par

clear X;
% calculation of the policy function X with Dynare
disp('Calculation of the policy function of the nonlinear mod-file')
X = FinIntGovDynare(par);

return;         % CRUCIAL STATEMENT IF WE USE FinIntGovDefMain IN FOR-LOOPS!!!!!!
% break;
%%
%--------------------------------------------------------------------------
% 5. Impulse Response Functions
%--------------------------------------------------------------------------

% calculate IRF's for a shock to productivity, a shock to capital quality,
% an unanticipated government spending shock and an interest rate shock


for j=2:2
    irf = FinIntGovIRF(par,X,LL,j);
    p = 1;
    if p==1
        FinIntGovPlot2(par,irf,par.default,lineshape,color,width);
    else
    end
end

